# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from akeyless.configuration import Configuration


class GatewayCreateProducerCertificateAutomation(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'admin_rotation_interval_days': 'int',
        'allow_subdomains': 'bool',
        'allowed_domains': 'list[str]',
        'auto_generated_folder': 'str',
        'delete_protection': 'str',
        'enable_admin_rotation': 'bool',
        'json': 'bool',
        'name': 'str',
        'producer_encryption_key_name': 'str',
        'root_first_in_chain': 'bool',
        'sign_using_akeyless_pki': 'bool',
        'signer_key_name': 'str',
        'store_private_key': 'bool',
        'tags': 'list[str]',
        'target_name': 'str',
        'token': 'str',
        'uid_token': 'str',
        'user_ttl': 'str',
        'venafi_api_key': 'str',
        'venafi_baseurl': 'str',
        'venafi_password': 'str',
        'venafi_use_tpp': 'bool',
        'venafi_username': 'str',
        'venafi_zone': 'str'
    }

    attribute_map = {
        'admin_rotation_interval_days': 'admin-rotation-interval-days',
        'allow_subdomains': 'allow-subdomains',
        'allowed_domains': 'allowed-domains',
        'auto_generated_folder': 'auto-generated-folder',
        'delete_protection': 'delete_protection',
        'enable_admin_rotation': 'enable-admin-rotation',
        'json': 'json',
        'name': 'name',
        'producer_encryption_key_name': 'producer-encryption-key-name',
        'root_first_in_chain': 'root-first-in-chain',
        'sign_using_akeyless_pki': 'sign-using-akeyless-pki',
        'signer_key_name': 'signer-key-name',
        'store_private_key': 'store-private-key',
        'tags': 'tags',
        'target_name': 'target-name',
        'token': 'token',
        'uid_token': 'uid-token',
        'user_ttl': 'user-ttl',
        'venafi_api_key': 'venafi-api-key',
        'venafi_baseurl': 'venafi-baseurl',
        'venafi_password': 'venafi-password',
        'venafi_use_tpp': 'venafi-use-tpp',
        'venafi_username': 'venafi-username',
        'venafi_zone': 'venafi-zone'
    }

    def __init__(self, admin_rotation_interval_days=0, allow_subdomains=None, allowed_domains=None, auto_generated_folder=None, delete_protection=None, enable_admin_rotation=False, json=None, name=None, producer_encryption_key_name=None, root_first_in_chain=None, sign_using_akeyless_pki=None, signer_key_name=None, store_private_key=None, tags=None, target_name=None, token=None, uid_token=None, user_ttl=None, venafi_api_key=None, venafi_baseurl=None, venafi_password=None, venafi_use_tpp=None, venafi_username=None, venafi_zone=None, local_vars_configuration=None):  # noqa: E501
        """GatewayCreateProducerCertificateAutomation - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._admin_rotation_interval_days = None
        self._allow_subdomains = None
        self._allowed_domains = None
        self._auto_generated_folder = None
        self._delete_protection = None
        self._enable_admin_rotation = None
        self._json = None
        self._name = None
        self._producer_encryption_key_name = None
        self._root_first_in_chain = None
        self._sign_using_akeyless_pki = None
        self._signer_key_name = None
        self._store_private_key = None
        self._tags = None
        self._target_name = None
        self._token = None
        self._uid_token = None
        self._user_ttl = None
        self._venafi_api_key = None
        self._venafi_baseurl = None
        self._venafi_password = None
        self._venafi_use_tpp = None
        self._venafi_username = None
        self._venafi_zone = None
        self.discriminator = None

        if admin_rotation_interval_days is not None:
            self.admin_rotation_interval_days = admin_rotation_interval_days
        if allow_subdomains is not None:
            self.allow_subdomains = allow_subdomains
        if allowed_domains is not None:
            self.allowed_domains = allowed_domains
        if auto_generated_folder is not None:
            self.auto_generated_folder = auto_generated_folder
        if delete_protection is not None:
            self.delete_protection = delete_protection
        if enable_admin_rotation is not None:
            self.enable_admin_rotation = enable_admin_rotation
        if json is not None:
            self.json = json
        self.name = name
        if producer_encryption_key_name is not None:
            self.producer_encryption_key_name = producer_encryption_key_name
        if root_first_in_chain is not None:
            self.root_first_in_chain = root_first_in_chain
        if sign_using_akeyless_pki is not None:
            self.sign_using_akeyless_pki = sign_using_akeyless_pki
        if signer_key_name is not None:
            self.signer_key_name = signer_key_name
        if store_private_key is not None:
            self.store_private_key = store_private_key
        if tags is not None:
            self.tags = tags
        if target_name is not None:
            self.target_name = target_name
        if token is not None:
            self.token = token
        if uid_token is not None:
            self.uid_token = uid_token
        if user_ttl is not None:
            self.user_ttl = user_ttl
        if venafi_api_key is not None:
            self.venafi_api_key = venafi_api_key
        if venafi_baseurl is not None:
            self.venafi_baseurl = venafi_baseurl
        if venafi_password is not None:
            self.venafi_password = venafi_password
        if venafi_use_tpp is not None:
            self.venafi_use_tpp = venafi_use_tpp
        if venafi_username is not None:
            self.venafi_username = venafi_username
        if venafi_zone is not None:
            self.venafi_zone = venafi_zone

    @property
    def admin_rotation_interval_days(self):
        """Gets the admin_rotation_interval_days of this GatewayCreateProducerCertificateAutomation.  # noqa: E501

        Admin credentials rotation interval (days)  # noqa: E501

        :return: The admin_rotation_interval_days of this GatewayCreateProducerCertificateAutomation.  # noqa: E501
        :rtype: int
        """
        return self._admin_rotation_interval_days

    @admin_rotation_interval_days.setter
    def admin_rotation_interval_days(self, admin_rotation_interval_days):
        """Sets the admin_rotation_interval_days of this GatewayCreateProducerCertificateAutomation.

        Admin credentials rotation interval (days)  # noqa: E501

        :param admin_rotation_interval_days: The admin_rotation_interval_days of this GatewayCreateProducerCertificateAutomation.  # noqa: E501
        :type: int
        """

        self._admin_rotation_interval_days = admin_rotation_interval_days

    @property
    def allow_subdomains(self):
        """Gets the allow_subdomains of this GatewayCreateProducerCertificateAutomation.  # noqa: E501

        Allow subdomains  # noqa: E501

        :return: The allow_subdomains of this GatewayCreateProducerCertificateAutomation.  # noqa: E501
        :rtype: bool
        """
        return self._allow_subdomains

    @allow_subdomains.setter
    def allow_subdomains(self, allow_subdomains):
        """Sets the allow_subdomains of this GatewayCreateProducerCertificateAutomation.

        Allow subdomains  # noqa: E501

        :param allow_subdomains: The allow_subdomains of this GatewayCreateProducerCertificateAutomation.  # noqa: E501
        :type: bool
        """

        self._allow_subdomains = allow_subdomains

    @property
    def allowed_domains(self):
        """Gets the allowed_domains of this GatewayCreateProducerCertificateAutomation.  # noqa: E501

        Allowed domains  # noqa: E501

        :return: The allowed_domains of this GatewayCreateProducerCertificateAutomation.  # noqa: E501
        :rtype: list[str]
        """
        return self._allowed_domains

    @allowed_domains.setter
    def allowed_domains(self, allowed_domains):
        """Sets the allowed_domains of this GatewayCreateProducerCertificateAutomation.

        Allowed domains  # noqa: E501

        :param allowed_domains: The allowed_domains of this GatewayCreateProducerCertificateAutomation.  # noqa: E501
        :type: list[str]
        """

        self._allowed_domains = allowed_domains

    @property
    def auto_generated_folder(self):
        """Gets the auto_generated_folder of this GatewayCreateProducerCertificateAutomation.  # noqa: E501

        Auto generated folder  # noqa: E501

        :return: The auto_generated_folder of this GatewayCreateProducerCertificateAutomation.  # noqa: E501
        :rtype: str
        """
        return self._auto_generated_folder

    @auto_generated_folder.setter
    def auto_generated_folder(self, auto_generated_folder):
        """Sets the auto_generated_folder of this GatewayCreateProducerCertificateAutomation.

        Auto generated folder  # noqa: E501

        :param auto_generated_folder: The auto_generated_folder of this GatewayCreateProducerCertificateAutomation.  # noqa: E501
        :type: str
        """

        self._auto_generated_folder = auto_generated_folder

    @property
    def delete_protection(self):
        """Gets the delete_protection of this GatewayCreateProducerCertificateAutomation.  # noqa: E501

        Protection from accidental deletion of this item  # noqa: E501

        :return: The delete_protection of this GatewayCreateProducerCertificateAutomation.  # noqa: E501
        :rtype: str
        """
        return self._delete_protection

    @delete_protection.setter
    def delete_protection(self, delete_protection):
        """Sets the delete_protection of this GatewayCreateProducerCertificateAutomation.

        Protection from accidental deletion of this item  # noqa: E501

        :param delete_protection: The delete_protection of this GatewayCreateProducerCertificateAutomation.  # noqa: E501
        :type: str
        """

        self._delete_protection = delete_protection

    @property
    def enable_admin_rotation(self):
        """Gets the enable_admin_rotation of this GatewayCreateProducerCertificateAutomation.  # noqa: E501

        Automatic admin credentials rotation  # noqa: E501

        :return: The enable_admin_rotation of this GatewayCreateProducerCertificateAutomation.  # noqa: E501
        :rtype: bool
        """
        return self._enable_admin_rotation

    @enable_admin_rotation.setter
    def enable_admin_rotation(self, enable_admin_rotation):
        """Sets the enable_admin_rotation of this GatewayCreateProducerCertificateAutomation.

        Automatic admin credentials rotation  # noqa: E501

        :param enable_admin_rotation: The enable_admin_rotation of this GatewayCreateProducerCertificateAutomation.  # noqa: E501
        :type: bool
        """

        self._enable_admin_rotation = enable_admin_rotation

    @property
    def json(self):
        """Gets the json of this GatewayCreateProducerCertificateAutomation.  # noqa: E501

        Set output format to JSON  # noqa: E501

        :return: The json of this GatewayCreateProducerCertificateAutomation.  # noqa: E501
        :rtype: bool
        """
        return self._json

    @json.setter
    def json(self, json):
        """Sets the json of this GatewayCreateProducerCertificateAutomation.

        Set output format to JSON  # noqa: E501

        :param json: The json of this GatewayCreateProducerCertificateAutomation.  # noqa: E501
        :type: bool
        """

        self._json = json

    @property
    def name(self):
        """Gets the name of this GatewayCreateProducerCertificateAutomation.  # noqa: E501

        Producer name  # noqa: E501

        :return: The name of this GatewayCreateProducerCertificateAutomation.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this GatewayCreateProducerCertificateAutomation.

        Producer name  # noqa: E501

        :param name: The name of this GatewayCreateProducerCertificateAutomation.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def producer_encryption_key_name(self):
        """Gets the producer_encryption_key_name of this GatewayCreateProducerCertificateAutomation.  # noqa: E501

        Dynamic producer encryption key  # noqa: E501

        :return: The producer_encryption_key_name of this GatewayCreateProducerCertificateAutomation.  # noqa: E501
        :rtype: str
        """
        return self._producer_encryption_key_name

    @producer_encryption_key_name.setter
    def producer_encryption_key_name(self, producer_encryption_key_name):
        """Sets the producer_encryption_key_name of this GatewayCreateProducerCertificateAutomation.

        Dynamic producer encryption key  # noqa: E501

        :param producer_encryption_key_name: The producer_encryption_key_name of this GatewayCreateProducerCertificateAutomation.  # noqa: E501
        :type: str
        """

        self._producer_encryption_key_name = producer_encryption_key_name

    @property
    def root_first_in_chain(self):
        """Gets the root_first_in_chain of this GatewayCreateProducerCertificateAutomation.  # noqa: E501

        Root first in chain  # noqa: E501

        :return: The root_first_in_chain of this GatewayCreateProducerCertificateAutomation.  # noqa: E501
        :rtype: bool
        """
        return self._root_first_in_chain

    @root_first_in_chain.setter
    def root_first_in_chain(self, root_first_in_chain):
        """Sets the root_first_in_chain of this GatewayCreateProducerCertificateAutomation.

        Root first in chain  # noqa: E501

        :param root_first_in_chain: The root_first_in_chain of this GatewayCreateProducerCertificateAutomation.  # noqa: E501
        :type: bool
        """

        self._root_first_in_chain = root_first_in_chain

    @property
    def sign_using_akeyless_pki(self):
        """Gets the sign_using_akeyless_pki of this GatewayCreateProducerCertificateAutomation.  # noqa: E501

        Use Akeyless PKI issuer or Venafi issuer  # noqa: E501

        :return: The sign_using_akeyless_pki of this GatewayCreateProducerCertificateAutomation.  # noqa: E501
        :rtype: bool
        """
        return self._sign_using_akeyless_pki

    @sign_using_akeyless_pki.setter
    def sign_using_akeyless_pki(self, sign_using_akeyless_pki):
        """Sets the sign_using_akeyless_pki of this GatewayCreateProducerCertificateAutomation.

        Use Akeyless PKI issuer or Venafi issuer  # noqa: E501

        :param sign_using_akeyless_pki: The sign_using_akeyless_pki of this GatewayCreateProducerCertificateAutomation.  # noqa: E501
        :type: bool
        """

        self._sign_using_akeyless_pki = sign_using_akeyless_pki

    @property
    def signer_key_name(self):
        """Gets the signer_key_name of this GatewayCreateProducerCertificateAutomation.  # noqa: E501

        Signer key name  # noqa: E501

        :return: The signer_key_name of this GatewayCreateProducerCertificateAutomation.  # noqa: E501
        :rtype: str
        """
        return self._signer_key_name

    @signer_key_name.setter
    def signer_key_name(self, signer_key_name):
        """Sets the signer_key_name of this GatewayCreateProducerCertificateAutomation.

        Signer key name  # noqa: E501

        :param signer_key_name: The signer_key_name of this GatewayCreateProducerCertificateAutomation.  # noqa: E501
        :type: str
        """

        self._signer_key_name = signer_key_name

    @property
    def store_private_key(self):
        """Gets the store_private_key of this GatewayCreateProducerCertificateAutomation.  # noqa: E501

        Store private key  # noqa: E501

        :return: The store_private_key of this GatewayCreateProducerCertificateAutomation.  # noqa: E501
        :rtype: bool
        """
        return self._store_private_key

    @store_private_key.setter
    def store_private_key(self, store_private_key):
        """Sets the store_private_key of this GatewayCreateProducerCertificateAutomation.

        Store private key  # noqa: E501

        :param store_private_key: The store_private_key of this GatewayCreateProducerCertificateAutomation.  # noqa: E501
        :type: bool
        """

        self._store_private_key = store_private_key

    @property
    def tags(self):
        """Gets the tags of this GatewayCreateProducerCertificateAutomation.  # noqa: E501

        List of the tags attached to this secret  # noqa: E501

        :return: The tags of this GatewayCreateProducerCertificateAutomation.  # noqa: E501
        :rtype: list[str]
        """
        return self._tags

    @tags.setter
    def tags(self, tags):
        """Sets the tags of this GatewayCreateProducerCertificateAutomation.

        List of the tags attached to this secret  # noqa: E501

        :param tags: The tags of this GatewayCreateProducerCertificateAutomation.  # noqa: E501
        :type: list[str]
        """

        self._tags = tags

    @property
    def target_name(self):
        """Gets the target_name of this GatewayCreateProducerCertificateAutomation.  # noqa: E501

        Target name  # noqa: E501

        :return: The target_name of this GatewayCreateProducerCertificateAutomation.  # noqa: E501
        :rtype: str
        """
        return self._target_name

    @target_name.setter
    def target_name(self, target_name):
        """Sets the target_name of this GatewayCreateProducerCertificateAutomation.

        Target name  # noqa: E501

        :param target_name: The target_name of this GatewayCreateProducerCertificateAutomation.  # noqa: E501
        :type: str
        """

        self._target_name = target_name

    @property
    def token(self):
        """Gets the token of this GatewayCreateProducerCertificateAutomation.  # noqa: E501

        Authentication token (see `/auth` and `/configure`)  # noqa: E501

        :return: The token of this GatewayCreateProducerCertificateAutomation.  # noqa: E501
        :rtype: str
        """
        return self._token

    @token.setter
    def token(self, token):
        """Sets the token of this GatewayCreateProducerCertificateAutomation.

        Authentication token (see `/auth` and `/configure`)  # noqa: E501

        :param token: The token of this GatewayCreateProducerCertificateAutomation.  # noqa: E501
        :type: str
        """

        self._token = token

    @property
    def uid_token(self):
        """Gets the uid_token of this GatewayCreateProducerCertificateAutomation.  # noqa: E501

        The universal identity token, Required only for universal_identity authentication  # noqa: E501

        :return: The uid_token of this GatewayCreateProducerCertificateAutomation.  # noqa: E501
        :rtype: str
        """
        return self._uid_token

    @uid_token.setter
    def uid_token(self, uid_token):
        """Sets the uid_token of this GatewayCreateProducerCertificateAutomation.

        The universal identity token, Required only for universal_identity authentication  # noqa: E501

        :param uid_token: The uid_token of this GatewayCreateProducerCertificateAutomation.  # noqa: E501
        :type: str
        """

        self._uid_token = uid_token

    @property
    def user_ttl(self):
        """Gets the user_ttl of this GatewayCreateProducerCertificateAutomation.  # noqa: E501

        User TTL in time.Duration format (2160h / 129600m / etc...). When using sign-using-akeyless-pki certificates created will have this validity period, otherwise the user-ttl is taken from the Validity Period field of the Zone's' Issuing Template. When using cert-manager it is advised to have a TTL of above 60 days (1440h). For more information - https://cert-manager.io/docs/usage/certificate/  # noqa: E501

        :return: The user_ttl of this GatewayCreateProducerCertificateAutomation.  # noqa: E501
        :rtype: str
        """
        return self._user_ttl

    @user_ttl.setter
    def user_ttl(self, user_ttl):
        """Sets the user_ttl of this GatewayCreateProducerCertificateAutomation.

        User TTL in time.Duration format (2160h / 129600m / etc...). When using sign-using-akeyless-pki certificates created will have this validity period, otherwise the user-ttl is taken from the Validity Period field of the Zone's' Issuing Template. When using cert-manager it is advised to have a TTL of above 60 days (1440h). For more information - https://cert-manager.io/docs/usage/certificate/  # noqa: E501

        :param user_ttl: The user_ttl of this GatewayCreateProducerCertificateAutomation.  # noqa: E501
        :type: str
        """

        self._user_ttl = user_ttl

    @property
    def venafi_api_key(self):
        """Gets the venafi_api_key of this GatewayCreateProducerCertificateAutomation.  # noqa: E501

        Venafi API key  # noqa: E501

        :return: The venafi_api_key of this GatewayCreateProducerCertificateAutomation.  # noqa: E501
        :rtype: str
        """
        return self._venafi_api_key

    @venafi_api_key.setter
    def venafi_api_key(self, venafi_api_key):
        """Sets the venafi_api_key of this GatewayCreateProducerCertificateAutomation.

        Venafi API key  # noqa: E501

        :param venafi_api_key: The venafi_api_key of this GatewayCreateProducerCertificateAutomation.  # noqa: E501
        :type: str
        """

        self._venafi_api_key = venafi_api_key

    @property
    def venafi_baseurl(self):
        """Gets the venafi_baseurl of this GatewayCreateProducerCertificateAutomation.  # noqa: E501

        Venafi Baseurl  # noqa: E501

        :return: The venafi_baseurl of this GatewayCreateProducerCertificateAutomation.  # noqa: E501
        :rtype: str
        """
        return self._venafi_baseurl

    @venafi_baseurl.setter
    def venafi_baseurl(self, venafi_baseurl):
        """Sets the venafi_baseurl of this GatewayCreateProducerCertificateAutomation.

        Venafi Baseurl  # noqa: E501

        :param venafi_baseurl: The venafi_baseurl of this GatewayCreateProducerCertificateAutomation.  # noqa: E501
        :type: str
        """

        self._venafi_baseurl = venafi_baseurl

    @property
    def venafi_password(self):
        """Gets the venafi_password of this GatewayCreateProducerCertificateAutomation.  # noqa: E501

        Venafi Password  # noqa: E501

        :return: The venafi_password of this GatewayCreateProducerCertificateAutomation.  # noqa: E501
        :rtype: str
        """
        return self._venafi_password

    @venafi_password.setter
    def venafi_password(self, venafi_password):
        """Sets the venafi_password of this GatewayCreateProducerCertificateAutomation.

        Venafi Password  # noqa: E501

        :param venafi_password: The venafi_password of this GatewayCreateProducerCertificateAutomation.  # noqa: E501
        :type: str
        """

        self._venafi_password = venafi_password

    @property
    def venafi_use_tpp(self):
        """Gets the venafi_use_tpp of this GatewayCreateProducerCertificateAutomation.  # noqa: E501

        Venafi using TPP  # noqa: E501

        :return: The venafi_use_tpp of this GatewayCreateProducerCertificateAutomation.  # noqa: E501
        :rtype: bool
        """
        return self._venafi_use_tpp

    @venafi_use_tpp.setter
    def venafi_use_tpp(self, venafi_use_tpp):
        """Sets the venafi_use_tpp of this GatewayCreateProducerCertificateAutomation.

        Venafi using TPP  # noqa: E501

        :param venafi_use_tpp: The venafi_use_tpp of this GatewayCreateProducerCertificateAutomation.  # noqa: E501
        :type: bool
        """

        self._venafi_use_tpp = venafi_use_tpp

    @property
    def venafi_username(self):
        """Gets the venafi_username of this GatewayCreateProducerCertificateAutomation.  # noqa: E501

        Venafi Username  # noqa: E501

        :return: The venafi_username of this GatewayCreateProducerCertificateAutomation.  # noqa: E501
        :rtype: str
        """
        return self._venafi_username

    @venafi_username.setter
    def venafi_username(self, venafi_username):
        """Sets the venafi_username of this GatewayCreateProducerCertificateAutomation.

        Venafi Username  # noqa: E501

        :param venafi_username: The venafi_username of this GatewayCreateProducerCertificateAutomation.  # noqa: E501
        :type: str
        """

        self._venafi_username = venafi_username

    @property
    def venafi_zone(self):
        """Gets the venafi_zone of this GatewayCreateProducerCertificateAutomation.  # noqa: E501

        Venafi Zone  # noqa: E501

        :return: The venafi_zone of this GatewayCreateProducerCertificateAutomation.  # noqa: E501
        :rtype: str
        """
        return self._venafi_zone

    @venafi_zone.setter
    def venafi_zone(self, venafi_zone):
        """Sets the venafi_zone of this GatewayCreateProducerCertificateAutomation.

        Venafi Zone  # noqa: E501

        :param venafi_zone: The venafi_zone of this GatewayCreateProducerCertificateAutomation.  # noqa: E501
        :type: str
        """

        self._venafi_zone = venafi_zone

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GatewayCreateProducerCertificateAutomation):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, GatewayCreateProducerCertificateAutomation):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from akeyless.configuration import Configuration


class PasswordPolicyInfo(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'password_length': 'int',
        'use_capital_letters': 'bool',
        'use_lower_letters': 'bool',
        'use_numbers': 'bool',
        'use_special_characters': 'bool'
    }

    attribute_map = {
        'password_length': 'password_length',
        'use_capital_letters': 'use_capital_letters',
        'use_lower_letters': 'use_lower_letters',
        'use_numbers': 'use_numbers',
        'use_special_characters': 'use_special_characters'
    }

    def __init__(self, password_length=None, use_capital_letters=None, use_lower_letters=None, use_numbers=None, use_special_characters=None, local_vars_configuration=None):  # noqa: E501
        """PasswordPolicyInfo - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._password_length = None
        self._use_capital_letters = None
        self._use_lower_letters = None
        self._use_numbers = None
        self._use_special_characters = None
        self.discriminator = None

        if password_length is not None:
            self.password_length = password_length
        if use_capital_letters is not None:
            self.use_capital_letters = use_capital_letters
        if use_lower_letters is not None:
            self.use_lower_letters = use_lower_letters
        if use_numbers is not None:
            self.use_numbers = use_numbers
        if use_special_characters is not None:
            self.use_special_characters = use_special_characters

    @property
    def password_length(self):
        """Gets the password_length of this PasswordPolicyInfo.  # noqa: E501


        :return: The password_length of this PasswordPolicyInfo.  # noqa: E501
        :rtype: int
        """
        return self._password_length

    @password_length.setter
    def password_length(self, password_length):
        """Sets the password_length of this PasswordPolicyInfo.


        :param password_length: The password_length of this PasswordPolicyInfo.  # noqa: E501
        :type: int
        """

        self._password_length = password_length

    @property
    def use_capital_letters(self):
        """Gets the use_capital_letters of this PasswordPolicyInfo.  # noqa: E501


        :return: The use_capital_letters of this PasswordPolicyInfo.  # noqa: E501
        :rtype: bool
        """
        return self._use_capital_letters

    @use_capital_letters.setter
    def use_capital_letters(self, use_capital_letters):
        """Sets the use_capital_letters of this PasswordPolicyInfo.


        :param use_capital_letters: The use_capital_letters of this PasswordPolicyInfo.  # noqa: E501
        :type: bool
        """

        self._use_capital_letters = use_capital_letters

    @property
    def use_lower_letters(self):
        """Gets the use_lower_letters of this PasswordPolicyInfo.  # noqa: E501


        :return: The use_lower_letters of this PasswordPolicyInfo.  # noqa: E501
        :rtype: bool
        """
        return self._use_lower_letters

    @use_lower_letters.setter
    def use_lower_letters(self, use_lower_letters):
        """Sets the use_lower_letters of this PasswordPolicyInfo.


        :param use_lower_letters: The use_lower_letters of this PasswordPolicyInfo.  # noqa: E501
        :type: bool
        """

        self._use_lower_letters = use_lower_letters

    @property
    def use_numbers(self):
        """Gets the use_numbers of this PasswordPolicyInfo.  # noqa: E501


        :return: The use_numbers of this PasswordPolicyInfo.  # noqa: E501
        :rtype: bool
        """
        return self._use_numbers

    @use_numbers.setter
    def use_numbers(self, use_numbers):
        """Sets the use_numbers of this PasswordPolicyInfo.


        :param use_numbers: The use_numbers of this PasswordPolicyInfo.  # noqa: E501
        :type: bool
        """

        self._use_numbers = use_numbers

    @property
    def use_special_characters(self):
        """Gets the use_special_characters of this PasswordPolicyInfo.  # noqa: E501


        :return: The use_special_characters of this PasswordPolicyInfo.  # noqa: E501
        :rtype: bool
        """
        return self._use_special_characters

    @use_special_characters.setter
    def use_special_characters(self, use_special_characters):
        """Sets the use_special_characters of this PasswordPolicyInfo.


        :param use_special_characters: The use_special_characters of this PasswordPolicyInfo.  # noqa: E501
        :type: bool
        """

        self._use_special_characters = use_special_characters

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PasswordPolicyInfo):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PasswordPolicyInfo):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from akeyless.configuration import Configuration


class Item(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'access_date': 'datetime',
        'access_request_status': 'str',
        'auto_rotate': 'bool',
        'cert_issuer_signer_key_name': 'str',
        'certificate_issue_details': 'CertificateIssueInfo',
        'certificates': 'str',
        'client_permissions': 'list[str]',
        'creation_date': 'datetime',
        'customer_fragment_id': 'str',
        'delete_protection': 'bool',
        'deletion_date': 'datetime',
        'display_id': 'str',
        'is_access_request_enabled': 'bool',
        'is_enabled': 'bool',
        'item_accessibility': 'int',
        'item_general_info': 'ItemGeneralInfo',
        'item_id': 'int',
        'item_metadata': 'str',
        'item_name': 'str',
        'item_size': 'int',
        'item_state': 'str',
        'item_sub_type': 'str',
        'item_tags': 'list[str]',
        'item_targets_assoc': 'list[ItemTargetAssociation]',
        'item_type': 'str',
        'item_versions': 'list[ItemVersion]',
        'last_version': 'int',
        'modification_date': 'datetime',
        'next_rotation_date': 'datetime',
        'protection_key_name': 'str',
        'protection_key_type': 'str',
        'public_value': 'str',
        'rotation_interval': 'int',
        'shared_by': 'RuleAssigner',
        'target_versions': 'list[TargetItemVersion]',
        'with_customer_fragment': 'bool'
    }

    attribute_map = {
        'access_date': 'access_date',
        'access_request_status': 'access_request_status',
        'auto_rotate': 'auto_rotate',
        'cert_issuer_signer_key_name': 'cert_issuer_signer_key_name',
        'certificate_issue_details': 'certificate_issue_details',
        'certificates': 'certificates',
        'client_permissions': 'client_permissions',
        'creation_date': 'creation_date',
        'customer_fragment_id': 'customer_fragment_id',
        'delete_protection': 'delete_protection',
        'deletion_date': 'deletion_date',
        'display_id': 'display_id',
        'is_access_request_enabled': 'is_access_request_enabled',
        'is_enabled': 'is_enabled',
        'item_accessibility': 'item_accessibility',
        'item_general_info': 'item_general_info',
        'item_id': 'item_id',
        'item_metadata': 'item_metadata',
        'item_name': 'item_name',
        'item_size': 'item_size',
        'item_state': 'item_state',
        'item_sub_type': 'item_sub_type',
        'item_tags': 'item_tags',
        'item_targets_assoc': 'item_targets_assoc',
        'item_type': 'item_type',
        'item_versions': 'item_versions',
        'last_version': 'last_version',
        'modification_date': 'modification_date',
        'next_rotation_date': 'next_rotation_date',
        'protection_key_name': 'protection_key_name',
        'protection_key_type': 'protection_key_type',
        'public_value': 'public_value',
        'rotation_interval': 'rotation_interval',
        'shared_by': 'shared_by',
        'target_versions': 'target_versions',
        'with_customer_fragment': 'with_customer_fragment'
    }

    def __init__(self, access_date=None, access_request_status=None, auto_rotate=None, cert_issuer_signer_key_name=None, certificate_issue_details=None, certificates=None, client_permissions=None, creation_date=None, customer_fragment_id=None, delete_protection=None, deletion_date=None, display_id=None, is_access_request_enabled=None, is_enabled=None, item_accessibility=None, item_general_info=None, item_id=None, item_metadata=None, item_name=None, item_size=None, item_state=None, item_sub_type=None, item_tags=None, item_targets_assoc=None, item_type=None, item_versions=None, last_version=None, modification_date=None, next_rotation_date=None, protection_key_name=None, protection_key_type=None, public_value=None, rotation_interval=None, shared_by=None, target_versions=None, with_customer_fragment=None, local_vars_configuration=None):  # noqa: E501
        """Item - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._access_date = None
        self._access_request_status = None
        self._auto_rotate = None
        self._cert_issuer_signer_key_name = None
        self._certificate_issue_details = None
        self._certificates = None
        self._client_permissions = None
        self._creation_date = None
        self._customer_fragment_id = None
        self._delete_protection = None
        self._deletion_date = None
        self._display_id = None
        self._is_access_request_enabled = None
        self._is_enabled = None
        self._item_accessibility = None
        self._item_general_info = None
        self._item_id = None
        self._item_metadata = None
        self._item_name = None
        self._item_size = None
        self._item_state = None
        self._item_sub_type = None
        self._item_tags = None
        self._item_targets_assoc = None
        self._item_type = None
        self._item_versions = None
        self._last_version = None
        self._modification_date = None
        self._next_rotation_date = None
        self._protection_key_name = None
        self._protection_key_type = None
        self._public_value = None
        self._rotation_interval = None
        self._shared_by = None
        self._target_versions = None
        self._with_customer_fragment = None
        self.discriminator = None

        if access_date is not None:
            self.access_date = access_date
        if access_request_status is not None:
            self.access_request_status = access_request_status
        if auto_rotate is not None:
            self.auto_rotate = auto_rotate
        if cert_issuer_signer_key_name is not None:
            self.cert_issuer_signer_key_name = cert_issuer_signer_key_name
        if certificate_issue_details is not None:
            self.certificate_issue_details = certificate_issue_details
        if certificates is not None:
            self.certificates = certificates
        if client_permissions is not None:
            self.client_permissions = client_permissions
        if creation_date is not None:
            self.creation_date = creation_date
        if customer_fragment_id is not None:
            self.customer_fragment_id = customer_fragment_id
        if delete_protection is not None:
            self.delete_protection = delete_protection
        if deletion_date is not None:
            self.deletion_date = deletion_date
        if display_id is not None:
            self.display_id = display_id
        if is_access_request_enabled is not None:
            self.is_access_request_enabled = is_access_request_enabled
        if is_enabled is not None:
            self.is_enabled = is_enabled
        if item_accessibility is not None:
            self.item_accessibility = item_accessibility
        if item_general_info is not None:
            self.item_general_info = item_general_info
        if item_id is not None:
            self.item_id = item_id
        if item_metadata is not None:
            self.item_metadata = item_metadata
        if item_name is not None:
            self.item_name = item_name
        if item_size is not None:
            self.item_size = item_size
        if item_state is not None:
            self.item_state = item_state
        if item_sub_type is not None:
            self.item_sub_type = item_sub_type
        if item_tags is not None:
            self.item_tags = item_tags
        if item_targets_assoc is not None:
            self.item_targets_assoc = item_targets_assoc
        if item_type is not None:
            self.item_type = item_type
        if item_versions is not None:
            self.item_versions = item_versions
        if last_version is not None:
            self.last_version = last_version
        if modification_date is not None:
            self.modification_date = modification_date
        if next_rotation_date is not None:
            self.next_rotation_date = next_rotation_date
        if protection_key_name is not None:
            self.protection_key_name = protection_key_name
        if protection_key_type is not None:
            self.protection_key_type = protection_key_type
        if public_value is not None:
            self.public_value = public_value
        if rotation_interval is not None:
            self.rotation_interval = rotation_interval
        if shared_by is not None:
            self.shared_by = shared_by
        if target_versions is not None:
            self.target_versions = target_versions
        if with_customer_fragment is not None:
            self.with_customer_fragment = with_customer_fragment

    @property
    def access_date(self):
        """Gets the access_date of this Item.  # noqa: E501


        :return: The access_date of this Item.  # noqa: E501
        :rtype: datetime
        """
        return self._access_date

    @access_date.setter
    def access_date(self, access_date):
        """Sets the access_date of this Item.


        :param access_date: The access_date of this Item.  # noqa: E501
        :type: datetime
        """

        self._access_date = access_date

    @property
    def access_request_status(self):
        """Gets the access_request_status of this Item.  # noqa: E501


        :return: The access_request_status of this Item.  # noqa: E501
        :rtype: str
        """
        return self._access_request_status

    @access_request_status.setter
    def access_request_status(self, access_request_status):
        """Sets the access_request_status of this Item.


        :param access_request_status: The access_request_status of this Item.  # noqa: E501
        :type: str
        """

        self._access_request_status = access_request_status

    @property
    def auto_rotate(self):
        """Gets the auto_rotate of this Item.  # noqa: E501


        :return: The auto_rotate of this Item.  # noqa: E501
        :rtype: bool
        """
        return self._auto_rotate

    @auto_rotate.setter
    def auto_rotate(self, auto_rotate):
        """Sets the auto_rotate of this Item.


        :param auto_rotate: The auto_rotate of this Item.  # noqa: E501
        :type: bool
        """

        self._auto_rotate = auto_rotate

    @property
    def cert_issuer_signer_key_name(self):
        """Gets the cert_issuer_signer_key_name of this Item.  # noqa: E501


        :return: The cert_issuer_signer_key_name of this Item.  # noqa: E501
        :rtype: str
        """
        return self._cert_issuer_signer_key_name

    @cert_issuer_signer_key_name.setter
    def cert_issuer_signer_key_name(self, cert_issuer_signer_key_name):
        """Sets the cert_issuer_signer_key_name of this Item.


        :param cert_issuer_signer_key_name: The cert_issuer_signer_key_name of this Item.  # noqa: E501
        :type: str
        """

        self._cert_issuer_signer_key_name = cert_issuer_signer_key_name

    @property
    def certificate_issue_details(self):
        """Gets the certificate_issue_details of this Item.  # noqa: E501


        :return: The certificate_issue_details of this Item.  # noqa: E501
        :rtype: CertificateIssueInfo
        """
        return self._certificate_issue_details

    @certificate_issue_details.setter
    def certificate_issue_details(self, certificate_issue_details):
        """Sets the certificate_issue_details of this Item.


        :param certificate_issue_details: The certificate_issue_details of this Item.  # noqa: E501
        :type: CertificateIssueInfo
        """

        self._certificate_issue_details = certificate_issue_details

    @property
    def certificates(self):
        """Gets the certificates of this Item.  # noqa: E501


        :return: The certificates of this Item.  # noqa: E501
        :rtype: str
        """
        return self._certificates

    @certificates.setter
    def certificates(self, certificates):
        """Sets the certificates of this Item.


        :param certificates: The certificates of this Item.  # noqa: E501
        :type: str
        """

        self._certificates = certificates

    @property
    def client_permissions(self):
        """Gets the client_permissions of this Item.  # noqa: E501


        :return: The client_permissions of this Item.  # noqa: E501
        :rtype: list[str]
        """
        return self._client_permissions

    @client_permissions.setter
    def client_permissions(self, client_permissions):
        """Sets the client_permissions of this Item.


        :param client_permissions: The client_permissions of this Item.  # noqa: E501
        :type: list[str]
        """

        self._client_permissions = client_permissions

    @property
    def creation_date(self):
        """Gets the creation_date of this Item.  # noqa: E501


        :return: The creation_date of this Item.  # noqa: E501
        :rtype: datetime
        """
        return self._creation_date

    @creation_date.setter
    def creation_date(self, creation_date):
        """Sets the creation_date of this Item.


        :param creation_date: The creation_date of this Item.  # noqa: E501
        :type: datetime
        """

        self._creation_date = creation_date

    @property
    def customer_fragment_id(self):
        """Gets the customer_fragment_id of this Item.  # noqa: E501


        :return: The customer_fragment_id of this Item.  # noqa: E501
        :rtype: str
        """
        return self._customer_fragment_id

    @customer_fragment_id.setter
    def customer_fragment_id(self, customer_fragment_id):
        """Sets the customer_fragment_id of this Item.


        :param customer_fragment_id: The customer_fragment_id of this Item.  # noqa: E501
        :type: str
        """

        self._customer_fragment_id = customer_fragment_id

    @property
    def delete_protection(self):
        """Gets the delete_protection of this Item.  # noqa: E501


        :return: The delete_protection of this Item.  # noqa: E501
        :rtype: bool
        """
        return self._delete_protection

    @delete_protection.setter
    def delete_protection(self, delete_protection):
        """Sets the delete_protection of this Item.


        :param delete_protection: The delete_protection of this Item.  # noqa: E501
        :type: bool
        """

        self._delete_protection = delete_protection

    @property
    def deletion_date(self):
        """Gets the deletion_date of this Item.  # noqa: E501


        :return: The deletion_date of this Item.  # noqa: E501
        :rtype: datetime
        """
        return self._deletion_date

    @deletion_date.setter
    def deletion_date(self, deletion_date):
        """Sets the deletion_date of this Item.


        :param deletion_date: The deletion_date of this Item.  # noqa: E501
        :type: datetime
        """

        self._deletion_date = deletion_date

    @property
    def display_id(self):
        """Gets the display_id of this Item.  # noqa: E501


        :return: The display_id of this Item.  # noqa: E501
        :rtype: str
        """
        return self._display_id

    @display_id.setter
    def display_id(self, display_id):
        """Sets the display_id of this Item.


        :param display_id: The display_id of this Item.  # noqa: E501
        :type: str
        """

        self._display_id = display_id

    @property
    def is_access_request_enabled(self):
        """Gets the is_access_request_enabled of this Item.  # noqa: E501


        :return: The is_access_request_enabled of this Item.  # noqa: E501
        :rtype: bool
        """
        return self._is_access_request_enabled

    @is_access_request_enabled.setter
    def is_access_request_enabled(self, is_access_request_enabled):
        """Sets the is_access_request_enabled of this Item.


        :param is_access_request_enabled: The is_access_request_enabled of this Item.  # noqa: E501
        :type: bool
        """

        self._is_access_request_enabled = is_access_request_enabled

    @property
    def is_enabled(self):
        """Gets the is_enabled of this Item.  # noqa: E501


        :return: The is_enabled of this Item.  # noqa: E501
        :rtype: bool
        """
        return self._is_enabled

    @is_enabled.setter
    def is_enabled(self, is_enabled):
        """Sets the is_enabled of this Item.


        :param is_enabled: The is_enabled of this Item.  # noqa: E501
        :type: bool
        """

        self._is_enabled = is_enabled

    @property
    def item_accessibility(self):
        """Gets the item_accessibility of this Item.  # noqa: E501


        :return: The item_accessibility of this Item.  # noqa: E501
        :rtype: int
        """
        return self._item_accessibility

    @item_accessibility.setter
    def item_accessibility(self, item_accessibility):
        """Sets the item_accessibility of this Item.


        :param item_accessibility: The item_accessibility of this Item.  # noqa: E501
        :type: int
        """

        self._item_accessibility = item_accessibility

    @property
    def item_general_info(self):
        """Gets the item_general_info of this Item.  # noqa: E501


        :return: The item_general_info of this Item.  # noqa: E501
        :rtype: ItemGeneralInfo
        """
        return self._item_general_info

    @item_general_info.setter
    def item_general_info(self, item_general_info):
        """Sets the item_general_info of this Item.


        :param item_general_info: The item_general_info of this Item.  # noqa: E501
        :type: ItemGeneralInfo
        """

        self._item_general_info = item_general_info

    @property
    def item_id(self):
        """Gets the item_id of this Item.  # noqa: E501


        :return: The item_id of this Item.  # noqa: E501
        :rtype: int
        """
        return self._item_id

    @item_id.setter
    def item_id(self, item_id):
        """Sets the item_id of this Item.


        :param item_id: The item_id of this Item.  # noqa: E501
        :type: int
        """

        self._item_id = item_id

    @property
    def item_metadata(self):
        """Gets the item_metadata of this Item.  # noqa: E501


        :return: The item_metadata of this Item.  # noqa: E501
        :rtype: str
        """
        return self._item_metadata

    @item_metadata.setter
    def item_metadata(self, item_metadata):
        """Sets the item_metadata of this Item.


        :param item_metadata: The item_metadata of this Item.  # noqa: E501
        :type: str
        """

        self._item_metadata = item_metadata

    @property
    def item_name(self):
        """Gets the item_name of this Item.  # noqa: E501


        :return: The item_name of this Item.  # noqa: E501
        :rtype: str
        """
        return self._item_name

    @item_name.setter
    def item_name(self, item_name):
        """Sets the item_name of this Item.


        :param item_name: The item_name of this Item.  # noqa: E501
        :type: str
        """

        self._item_name = item_name

    @property
    def item_size(self):
        """Gets the item_size of this Item.  # noqa: E501


        :return: The item_size of this Item.  # noqa: E501
        :rtype: int
        """
        return self._item_size

    @item_size.setter
    def item_size(self, item_size):
        """Sets the item_size of this Item.


        :param item_size: The item_size of this Item.  # noqa: E501
        :type: int
        """

        self._item_size = item_size

    @property
    def item_state(self):
        """Gets the item_state of this Item.  # noqa: E501

        ItemState defines the different states an Item can be in  # noqa: E501

        :return: The item_state of this Item.  # noqa: E501
        :rtype: str
        """
        return self._item_state

    @item_state.setter
    def item_state(self, item_state):
        """Sets the item_state of this Item.

        ItemState defines the different states an Item can be in  # noqa: E501

        :param item_state: The item_state of this Item.  # noqa: E501
        :type: str
        """

        self._item_state = item_state

    @property
    def item_sub_type(self):
        """Gets the item_sub_type of this Item.  # noqa: E501


        :return: The item_sub_type of this Item.  # noqa: E501
        :rtype: str
        """
        return self._item_sub_type

    @item_sub_type.setter
    def item_sub_type(self, item_sub_type):
        """Sets the item_sub_type of this Item.


        :param item_sub_type: The item_sub_type of this Item.  # noqa: E501
        :type: str
        """

        self._item_sub_type = item_sub_type

    @property
    def item_tags(self):
        """Gets the item_tags of this Item.  # noqa: E501


        :return: The item_tags of this Item.  # noqa: E501
        :rtype: list[str]
        """
        return self._item_tags

    @item_tags.setter
    def item_tags(self, item_tags):
        """Sets the item_tags of this Item.


        :param item_tags: The item_tags of this Item.  # noqa: E501
        :type: list[str]
        """

        self._item_tags = item_tags

    @property
    def item_targets_assoc(self):
        """Gets the item_targets_assoc of this Item.  # noqa: E501


        :return: The item_targets_assoc of this Item.  # noqa: E501
        :rtype: list[ItemTargetAssociation]
        """
        return self._item_targets_assoc

    @item_targets_assoc.setter
    def item_targets_assoc(self, item_targets_assoc):
        """Sets the item_targets_assoc of this Item.


        :param item_targets_assoc: The item_targets_assoc of this Item.  # noqa: E501
        :type: list[ItemTargetAssociation]
        """

        self._item_targets_assoc = item_targets_assoc

    @property
    def item_type(self):
        """Gets the item_type of this Item.  # noqa: E501


        :return: The item_type of this Item.  # noqa: E501
        :rtype: str
        """
        return self._item_type

    @item_type.setter
    def item_type(self, item_type):
        """Sets the item_type of this Item.


        :param item_type: The item_type of this Item.  # noqa: E501
        :type: str
        """

        self._item_type = item_type

    @property
    def item_versions(self):
        """Gets the item_versions of this Item.  # noqa: E501


        :return: The item_versions of this Item.  # noqa: E501
        :rtype: list[ItemVersion]
        """
        return self._item_versions

    @item_versions.setter
    def item_versions(self, item_versions):
        """Sets the item_versions of this Item.


        :param item_versions: The item_versions of this Item.  # noqa: E501
        :type: list[ItemVersion]
        """

        self._item_versions = item_versions

    @property
    def last_version(self):
        """Gets the last_version of this Item.  # noqa: E501


        :return: The last_version of this Item.  # noqa: E501
        :rtype: int
        """
        return self._last_version

    @last_version.setter
    def last_version(self, last_version):
        """Sets the last_version of this Item.


        :param last_version: The last_version of this Item.  # noqa: E501
        :type: int
        """

        self._last_version = last_version

    @property
    def modification_date(self):
        """Gets the modification_date of this Item.  # noqa: E501


        :return: The modification_date of this Item.  # noqa: E501
        :rtype: datetime
        """
        return self._modification_date

    @modification_date.setter
    def modification_date(self, modification_date):
        """Sets the modification_date of this Item.


        :param modification_date: The modification_date of this Item.  # noqa: E501
        :type: datetime
        """

        self._modification_date = modification_date

    @property
    def next_rotation_date(self):
        """Gets the next_rotation_date of this Item.  # noqa: E501


        :return: The next_rotation_date of this Item.  # noqa: E501
        :rtype: datetime
        """
        return self._next_rotation_date

    @next_rotation_date.setter
    def next_rotation_date(self, next_rotation_date):
        """Sets the next_rotation_date of this Item.


        :param next_rotation_date: The next_rotation_date of this Item.  # noqa: E501
        :type: datetime
        """

        self._next_rotation_date = next_rotation_date

    @property
    def protection_key_name(self):
        """Gets the protection_key_name of this Item.  # noqa: E501


        :return: The protection_key_name of this Item.  # noqa: E501
        :rtype: str
        """
        return self._protection_key_name

    @protection_key_name.setter
    def protection_key_name(self, protection_key_name):
        """Sets the protection_key_name of this Item.


        :param protection_key_name: The protection_key_name of this Item.  # noqa: E501
        :type: str
        """

        self._protection_key_name = protection_key_name

    @property
    def protection_key_type(self):
        """Gets the protection_key_type of this Item.  # noqa: E501


        :return: The protection_key_type of this Item.  # noqa: E501
        :rtype: str
        """
        return self._protection_key_type

    @protection_key_type.setter
    def protection_key_type(self, protection_key_type):
        """Sets the protection_key_type of this Item.


        :param protection_key_type: The protection_key_type of this Item.  # noqa: E501
        :type: str
        """

        self._protection_key_type = protection_key_type

    @property
    def public_value(self):
        """Gets the public_value of this Item.  # noqa: E501


        :return: The public_value of this Item.  # noqa: E501
        :rtype: str
        """
        return self._public_value

    @public_value.setter
    def public_value(self, public_value):
        """Sets the public_value of this Item.


        :param public_value: The public_value of this Item.  # noqa: E501
        :type: str
        """

        self._public_value = public_value

    @property
    def rotation_interval(self):
        """Gets the rotation_interval of this Item.  # noqa: E501


        :return: The rotation_interval of this Item.  # noqa: E501
        :rtype: int
        """
        return self._rotation_interval

    @rotation_interval.setter
    def rotation_interval(self, rotation_interval):
        """Sets the rotation_interval of this Item.


        :param rotation_interval: The rotation_interval of this Item.  # noqa: E501
        :type: int
        """

        self._rotation_interval = rotation_interval

    @property
    def shared_by(self):
        """Gets the shared_by of this Item.  # noqa: E501


        :return: The shared_by of this Item.  # noqa: E501
        :rtype: RuleAssigner
        """
        return self._shared_by

    @shared_by.setter
    def shared_by(self, shared_by):
        """Sets the shared_by of this Item.


        :param shared_by: The shared_by of this Item.  # noqa: E501
        :type: RuleAssigner
        """

        self._shared_by = shared_by

    @property
    def target_versions(self):
        """Gets the target_versions of this Item.  # noqa: E501


        :return: The target_versions of this Item.  # noqa: E501
        :rtype: list[TargetItemVersion]
        """
        return self._target_versions

    @target_versions.setter
    def target_versions(self, target_versions):
        """Sets the target_versions of this Item.


        :param target_versions: The target_versions of this Item.  # noqa: E501
        :type: list[TargetItemVersion]
        """

        self._target_versions = target_versions

    @property
    def with_customer_fragment(self):
        """Gets the with_customer_fragment of this Item.  # noqa: E501


        :return: The with_customer_fragment of this Item.  # noqa: E501
        :rtype: bool
        """
        return self._with_customer_fragment

    @with_customer_fragment.setter
    def with_customer_fragment(self, with_customer_fragment):
        """Sets the with_customer_fragment of this Item.


        :param with_customer_fragment: The with_customer_fragment of this Item.  # noqa: E501
        :type: bool
        """

        self._with_customer_fragment = with_customer_fragment

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Item):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Item):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import akeyless
from akeyless.models.secure_remote_access import SecureRemoteAccess  # noqa: E501
from akeyless.rest import ApiException

class TestSecureRemoteAccess(unittest.TestCase):
    """SecureRemoteAccess unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test SecureRemoteAccess
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = akeyless.models.secure_remote_access.SecureRemoteAccess()  # noqa: E501
        if include_optional :
            return SecureRemoteAccess(
                account_id = '0', 
                allow_port_forwarding = True, 
                bastion_api = '0', 
                bastion_issuer = '0', 
                bastion_issuer_id = 56, 
                bastion_ssh = '0', 
                category = '0', 
                dashboard_url = '0', 
                db_name = '0', 
                domain = '0', 
                enable = True, 
                endpoint = '0', 
                host = [
                    '0'
                    ], 
                is_cli = True, 
                is_web = True, 
                isolated = True, 
                native = True, 
                region = '0', 
                schema = '0', 
                ssh_password = True, 
                ssh_private_key = True, 
                ssh_user = '0', 
                url = '0'
            )
        else :
            return SecureRemoteAccess(
        )

    def testSecureRemoteAccess(self):
        """Test SecureRemoteAccess"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from akeyless.configuration import Configuration


class AkeylessGatewayConfig(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'admins': 'AdminsConfigPart',
        'cache': 'CacheConfigPart',
        'cf': 'CFConfigPart',
        'config_protection_key_name': 'str',
        'general': 'GeneralConfigPart',
        'k8s_auths': 'K8SAuthsConfigPart',
        'kmip_clients': 'KMIPConfigPart',
        'ldap': 'LdapConfigPart',
        'leadership': 'LeadershipConfigPart',
        'log_forwarding': 'LogForwardingConfigPart',
        'message_queue_info': 'GatewayMessageQueueInfo',
        'migrations': 'MigrationsConfigPart',
        'producers': 'ProducersConfigPart',
        'rotators': 'RotatorsConfigPart',
        'saml': 'DefaultConfigPart',
        'version': 'int'
    }

    attribute_map = {
        'admins': 'admins',
        'cache': 'cache',
        'cf': 'cf',
        'config_protection_key_name': 'config_protection_key_name',
        'general': 'general',
        'k8s_auths': 'k8s_auths',
        'kmip_clients': 'kmip_clients',
        'ldap': 'ldap',
        'leadership': 'leadership',
        'log_forwarding': 'log_forwarding',
        'message_queue_info': 'message_queue_info',
        'migrations': 'migrations',
        'producers': 'producers',
        'rotators': 'rotators',
        'saml': 'saml',
        'version': 'version'
    }

    def __init__(self, admins=None, cache=None, cf=None, config_protection_key_name=None, general=None, k8s_auths=None, kmip_clients=None, ldap=None, leadership=None, log_forwarding=None, message_queue_info=None, migrations=None, producers=None, rotators=None, saml=None, version=None, local_vars_configuration=None):  # noqa: E501
        """AkeylessGatewayConfig - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._admins = None
        self._cache = None
        self._cf = None
        self._config_protection_key_name = None
        self._general = None
        self._k8s_auths = None
        self._kmip_clients = None
        self._ldap = None
        self._leadership = None
        self._log_forwarding = None
        self._message_queue_info = None
        self._migrations = None
        self._producers = None
        self._rotators = None
        self._saml = None
        self._version = None
        self.discriminator = None

        if admins is not None:
            self.admins = admins
        if cache is not None:
            self.cache = cache
        if cf is not None:
            self.cf = cf
        if config_protection_key_name is not None:
            self.config_protection_key_name = config_protection_key_name
        if general is not None:
            self.general = general
        if k8s_auths is not None:
            self.k8s_auths = k8s_auths
        if kmip_clients is not None:
            self.kmip_clients = kmip_clients
        if ldap is not None:
            self.ldap = ldap
        if leadership is not None:
            self.leadership = leadership
        if log_forwarding is not None:
            self.log_forwarding = log_forwarding
        if message_queue_info is not None:
            self.message_queue_info = message_queue_info
        if migrations is not None:
            self.migrations = migrations
        if producers is not None:
            self.producers = producers
        if rotators is not None:
            self.rotators = rotators
        if saml is not None:
            self.saml = saml
        if version is not None:
            self.version = version

    @property
    def admins(self):
        """Gets the admins of this AkeylessGatewayConfig.  # noqa: E501


        :return: The admins of this AkeylessGatewayConfig.  # noqa: E501
        :rtype: AdminsConfigPart
        """
        return self._admins

    @admins.setter
    def admins(self, admins):
        """Sets the admins of this AkeylessGatewayConfig.


        :param admins: The admins of this AkeylessGatewayConfig.  # noqa: E501
        :type: AdminsConfigPart
        """

        self._admins = admins

    @property
    def cache(self):
        """Gets the cache of this AkeylessGatewayConfig.  # noqa: E501


        :return: The cache of this AkeylessGatewayConfig.  # noqa: E501
        :rtype: CacheConfigPart
        """
        return self._cache

    @cache.setter
    def cache(self, cache):
        """Sets the cache of this AkeylessGatewayConfig.


        :param cache: The cache of this AkeylessGatewayConfig.  # noqa: E501
        :type: CacheConfigPart
        """

        self._cache = cache

    @property
    def cf(self):
        """Gets the cf of this AkeylessGatewayConfig.  # noqa: E501


        :return: The cf of this AkeylessGatewayConfig.  # noqa: E501
        :rtype: CFConfigPart
        """
        return self._cf

    @cf.setter
    def cf(self, cf):
        """Sets the cf of this AkeylessGatewayConfig.


        :param cf: The cf of this AkeylessGatewayConfig.  # noqa: E501
        :type: CFConfigPart
        """

        self._cf = cf

    @property
    def config_protection_key_name(self):
        """Gets the config_protection_key_name of this AkeylessGatewayConfig.  # noqa: E501


        :return: The config_protection_key_name of this AkeylessGatewayConfig.  # noqa: E501
        :rtype: str
        """
        return self._config_protection_key_name

    @config_protection_key_name.setter
    def config_protection_key_name(self, config_protection_key_name):
        """Sets the config_protection_key_name of this AkeylessGatewayConfig.


        :param config_protection_key_name: The config_protection_key_name of this AkeylessGatewayConfig.  # noqa: E501
        :type: str
        """

        self._config_protection_key_name = config_protection_key_name

    @property
    def general(self):
        """Gets the general of this AkeylessGatewayConfig.  # noqa: E501


        :return: The general of this AkeylessGatewayConfig.  # noqa: E501
        :rtype: GeneralConfigPart
        """
        return self._general

    @general.setter
    def general(self, general):
        """Sets the general of this AkeylessGatewayConfig.


        :param general: The general of this AkeylessGatewayConfig.  # noqa: E501
        :type: GeneralConfigPart
        """

        self._general = general

    @property
    def k8s_auths(self):
        """Gets the k8s_auths of this AkeylessGatewayConfig.  # noqa: E501


        :return: The k8s_auths of this AkeylessGatewayConfig.  # noqa: E501
        :rtype: K8SAuthsConfigPart
        """
        return self._k8s_auths

    @k8s_auths.setter
    def k8s_auths(self, k8s_auths):
        """Sets the k8s_auths of this AkeylessGatewayConfig.


        :param k8s_auths: The k8s_auths of this AkeylessGatewayConfig.  # noqa: E501
        :type: K8SAuthsConfigPart
        """

        self._k8s_auths = k8s_auths

    @property
    def kmip_clients(self):
        """Gets the kmip_clients of this AkeylessGatewayConfig.  # noqa: E501


        :return: The kmip_clients of this AkeylessGatewayConfig.  # noqa: E501
        :rtype: KMIPConfigPart
        """
        return self._kmip_clients

    @kmip_clients.setter
    def kmip_clients(self, kmip_clients):
        """Sets the kmip_clients of this AkeylessGatewayConfig.


        :param kmip_clients: The kmip_clients of this AkeylessGatewayConfig.  # noqa: E501
        :type: KMIPConfigPart
        """

        self._kmip_clients = kmip_clients

    @property
    def ldap(self):
        """Gets the ldap of this AkeylessGatewayConfig.  # noqa: E501


        :return: The ldap of this AkeylessGatewayConfig.  # noqa: E501
        :rtype: LdapConfigPart
        """
        return self._ldap

    @ldap.setter
    def ldap(self, ldap):
        """Sets the ldap of this AkeylessGatewayConfig.


        :param ldap: The ldap of this AkeylessGatewayConfig.  # noqa: E501
        :type: LdapConfigPart
        """

        self._ldap = ldap

    @property
    def leadership(self):
        """Gets the leadership of this AkeylessGatewayConfig.  # noqa: E501


        :return: The leadership of this AkeylessGatewayConfig.  # noqa: E501
        :rtype: LeadershipConfigPart
        """
        return self._leadership

    @leadership.setter
    def leadership(self, leadership):
        """Sets the leadership of this AkeylessGatewayConfig.


        :param leadership: The leadership of this AkeylessGatewayConfig.  # noqa: E501
        :type: LeadershipConfigPart
        """

        self._leadership = leadership

    @property
    def log_forwarding(self):
        """Gets the log_forwarding of this AkeylessGatewayConfig.  # noqa: E501


        :return: The log_forwarding of this AkeylessGatewayConfig.  # noqa: E501
        :rtype: LogForwardingConfigPart
        """
        return self._log_forwarding

    @log_forwarding.setter
    def log_forwarding(self, log_forwarding):
        """Sets the log_forwarding of this AkeylessGatewayConfig.


        :param log_forwarding: The log_forwarding of this AkeylessGatewayConfig.  # noqa: E501
        :type: LogForwardingConfigPart
        """

        self._log_forwarding = log_forwarding

    @property
    def message_queue_info(self):
        """Gets the message_queue_info of this AkeylessGatewayConfig.  # noqa: E501


        :return: The message_queue_info of this AkeylessGatewayConfig.  # noqa: E501
        :rtype: GatewayMessageQueueInfo
        """
        return self._message_queue_info

    @message_queue_info.setter
    def message_queue_info(self, message_queue_info):
        """Sets the message_queue_info of this AkeylessGatewayConfig.


        :param message_queue_info: The message_queue_info of this AkeylessGatewayConfig.  # noqa: E501
        :type: GatewayMessageQueueInfo
        """

        self._message_queue_info = message_queue_info

    @property
    def migrations(self):
        """Gets the migrations of this AkeylessGatewayConfig.  # noqa: E501


        :return: The migrations of this AkeylessGatewayConfig.  # noqa: E501
        :rtype: MigrationsConfigPart
        """
        return self._migrations

    @migrations.setter
    def migrations(self, migrations):
        """Sets the migrations of this AkeylessGatewayConfig.


        :param migrations: The migrations of this AkeylessGatewayConfig.  # noqa: E501
        :type: MigrationsConfigPart
        """

        self._migrations = migrations

    @property
    def producers(self):
        """Gets the producers of this AkeylessGatewayConfig.  # noqa: E501


        :return: The producers of this AkeylessGatewayConfig.  # noqa: E501
        :rtype: ProducersConfigPart
        """
        return self._producers

    @producers.setter
    def producers(self, producers):
        """Sets the producers of this AkeylessGatewayConfig.


        :param producers: The producers of this AkeylessGatewayConfig.  # noqa: E501
        :type: ProducersConfigPart
        """

        self._producers = producers

    @property
    def rotators(self):
        """Gets the rotators of this AkeylessGatewayConfig.  # noqa: E501


        :return: The rotators of this AkeylessGatewayConfig.  # noqa: E501
        :rtype: RotatorsConfigPart
        """
        return self._rotators

    @rotators.setter
    def rotators(self, rotators):
        """Sets the rotators of this AkeylessGatewayConfig.


        :param rotators: The rotators of this AkeylessGatewayConfig.  # noqa: E501
        :type: RotatorsConfigPart
        """

        self._rotators = rotators

    @property
    def saml(self):
        """Gets the saml of this AkeylessGatewayConfig.  # noqa: E501


        :return: The saml of this AkeylessGatewayConfig.  # noqa: E501
        :rtype: DefaultConfigPart
        """
        return self._saml

    @saml.setter
    def saml(self, saml):
        """Sets the saml of this AkeylessGatewayConfig.


        :param saml: The saml of this AkeylessGatewayConfig.  # noqa: E501
        :type: DefaultConfigPart
        """

        self._saml = saml

    @property
    def version(self):
        """Gets the version of this AkeylessGatewayConfig.  # noqa: E501


        :return: The version of this AkeylessGatewayConfig.  # noqa: E501
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this AkeylessGatewayConfig.


        :param version: The version of this AkeylessGatewayConfig.  # noqa: E501
        :type: int
        """

        self._version = version

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AkeylessGatewayConfig):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AkeylessGatewayConfig):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from akeyless.configuration import Configuration


class UpdateAccountSettings(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'address': 'str',
        'city': 'str',
        'company_name': 'str',
        'country': 'str',
        'default_versioning': 'str',
        'dp_enable_classic_key_protection': 'str',
        'item_type': 'str',
        'json': 'bool',
        'jwt_ttl_default': 'int',
        'jwt_ttl_max': 'int',
        'jwt_ttl_min': 'int',
        'max_versions': 'str',
        'password_length': 'int',
        'phone': 'str',
        'postal_code': 'str',
        'token': 'str',
        'uid_token': 'str',
        'use_lower_letters': 'str',
        'use_numbers': 'str',
        'use_special_characters': 'str',
        'use_capital_letters': 'str'
    }

    attribute_map = {
        'address': 'address',
        'city': 'city',
        'company_name': 'company-name',
        'country': 'country',
        'default_versioning': 'default-versioning',
        'dp_enable_classic_key_protection': 'dp-enable-classic-key-protection',
        'item_type': 'item-type',
        'json': 'json',
        'jwt_ttl_default': 'jwt-ttl-default',
        'jwt_ttl_max': 'jwt-ttl-max',
        'jwt_ttl_min': 'jwt-ttl-min',
        'max_versions': 'max-versions',
        'password_length': 'password-length',
        'phone': 'phone',
        'postal_code': 'postal-code',
        'token': 'token',
        'uid_token': 'uid-token',
        'use_lower_letters': 'use-lower-letters',
        'use_numbers': 'use-numbers',
        'use_special_characters': 'use-special-characters',
        'use_capital_letters': 'use_capital-letters'
    }

    def __init__(self, address=None, city=None, company_name=None, country=None, default_versioning=None, dp_enable_classic_key_protection=None, item_type=None, json=None, jwt_ttl_default=None, jwt_ttl_max=None, jwt_ttl_min=None, max_versions=None, password_length=None, phone=None, postal_code=None, token=None, uid_token=None, use_lower_letters=None, use_numbers=None, use_special_characters=None, use_capital_letters=None, local_vars_configuration=None):  # noqa: E501
        """UpdateAccountSettings - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._address = None
        self._city = None
        self._company_name = None
        self._country = None
        self._default_versioning = None
        self._dp_enable_classic_key_protection = None
        self._item_type = None
        self._json = None
        self._jwt_ttl_default = None
        self._jwt_ttl_max = None
        self._jwt_ttl_min = None
        self._max_versions = None
        self._password_length = None
        self._phone = None
        self._postal_code = None
        self._token = None
        self._uid_token = None
        self._use_lower_letters = None
        self._use_numbers = None
        self._use_special_characters = None
        self._use_capital_letters = None
        self.discriminator = None

        if address is not None:
            self.address = address
        if city is not None:
            self.city = city
        if company_name is not None:
            self.company_name = company_name
        if country is not None:
            self.country = country
        if default_versioning is not None:
            self.default_versioning = default_versioning
        if dp_enable_classic_key_protection is not None:
            self.dp_enable_classic_key_protection = dp_enable_classic_key_protection
        if item_type is not None:
            self.item_type = item_type
        if json is not None:
            self.json = json
        if jwt_ttl_default is not None:
            self.jwt_ttl_default = jwt_ttl_default
        if jwt_ttl_max is not None:
            self.jwt_ttl_max = jwt_ttl_max
        if jwt_ttl_min is not None:
            self.jwt_ttl_min = jwt_ttl_min
        if max_versions is not None:
            self.max_versions = max_versions
        if password_length is not None:
            self.password_length = password_length
        if phone is not None:
            self.phone = phone
        if postal_code is not None:
            self.postal_code = postal_code
        if token is not None:
            self.token = token
        if uid_token is not None:
            self.uid_token = uid_token
        if use_lower_letters is not None:
            self.use_lower_letters = use_lower_letters
        if use_numbers is not None:
            self.use_numbers = use_numbers
        if use_special_characters is not None:
            self.use_special_characters = use_special_characters
        if use_capital_letters is not None:
            self.use_capital_letters = use_capital_letters

    @property
    def address(self):
        """Gets the address of this UpdateAccountSettings.  # noqa: E501

        Address  # noqa: E501

        :return: The address of this UpdateAccountSettings.  # noqa: E501
        :rtype: str
        """
        return self._address

    @address.setter
    def address(self, address):
        """Sets the address of this UpdateAccountSettings.

        Address  # noqa: E501

        :param address: The address of this UpdateAccountSettings.  # noqa: E501
        :type: str
        """

        self._address = address

    @property
    def city(self):
        """Gets the city of this UpdateAccountSettings.  # noqa: E501

        City  # noqa: E501

        :return: The city of this UpdateAccountSettings.  # noqa: E501
        :rtype: str
        """
        return self._city

    @city.setter
    def city(self, city):
        """Sets the city of this UpdateAccountSettings.

        City  # noqa: E501

        :param city: The city of this UpdateAccountSettings.  # noqa: E501
        :type: str
        """

        self._city = city

    @property
    def company_name(self):
        """Gets the company_name of this UpdateAccountSettings.  # noqa: E501

        Company name  # noqa: E501

        :return: The company_name of this UpdateAccountSettings.  # noqa: E501
        :rtype: str
        """
        return self._company_name

    @company_name.setter
    def company_name(self, company_name):
        """Sets the company_name of this UpdateAccountSettings.

        Company name  # noqa: E501

        :param company_name: The company_name of this UpdateAccountSettings.  # noqa: E501
        :type: str
        """

        self._company_name = company_name

    @property
    def country(self):
        """Gets the country of this UpdateAccountSettings.  # noqa: E501

        Country  # noqa: E501

        :return: The country of this UpdateAccountSettings.  # noqa: E501
        :rtype: str
        """
        return self._country

    @country.setter
    def country(self, country):
        """Sets the country of this UpdateAccountSettings.

        Country  # noqa: E501

        :param country: The country of this UpdateAccountSettings.  # noqa: E501
        :type: str
        """

        self._country = country

    @property
    def default_versioning(self):
        """Gets the default_versioning of this UpdateAccountSettings.  # noqa: E501

        Should create version by default  # noqa: E501

        :return: The default_versioning of this UpdateAccountSettings.  # noqa: E501
        :rtype: str
        """
        return self._default_versioning

    @default_versioning.setter
    def default_versioning(self, default_versioning):
        """Sets the default_versioning of this UpdateAccountSettings.

        Should create version by default  # noqa: E501

        :param default_versioning: The default_versioning of this UpdateAccountSettings.  # noqa: E501
        :type: str
        """

        self._default_versioning = default_versioning

    @property
    def dp_enable_classic_key_protection(self):
        """Gets the dp_enable_classic_key_protection of this UpdateAccountSettings.  # noqa: E501

        Enable classic key protection [\"true\"/\"false\"]  # noqa: E501

        :return: The dp_enable_classic_key_protection of this UpdateAccountSettings.  # noqa: E501
        :rtype: str
        """
        return self._dp_enable_classic_key_protection

    @dp_enable_classic_key_protection.setter
    def dp_enable_classic_key_protection(self, dp_enable_classic_key_protection):
        """Sets the dp_enable_classic_key_protection of this UpdateAccountSettings.

        Enable classic key protection [\"true\"/\"false\"]  # noqa: E501

        :param dp_enable_classic_key_protection: The dp_enable_classic_key_protection of this UpdateAccountSettings.  # noqa: E501
        :type: str
        """

        self._dp_enable_classic_key_protection = dp_enable_classic_key_protection

    @property
    def item_type(self):
        """Gets the item_type of this UpdateAccountSettings.  # noqa: E501

        VersionSettingsObjectType defines object types for account version settings  # noqa: E501

        :return: The item_type of this UpdateAccountSettings.  # noqa: E501
        :rtype: str
        """
        return self._item_type

    @item_type.setter
    def item_type(self, item_type):
        """Sets the item_type of this UpdateAccountSettings.

        VersionSettingsObjectType defines object types for account version settings  # noqa: E501

        :param item_type: The item_type of this UpdateAccountSettings.  # noqa: E501
        :type: str
        """

        self._item_type = item_type

    @property
    def json(self):
        """Gets the json of this UpdateAccountSettings.  # noqa: E501

        Set output format to JSON  # noqa: E501

        :return: The json of this UpdateAccountSettings.  # noqa: E501
        :rtype: bool
        """
        return self._json

    @json.setter
    def json(self, json):
        """Sets the json of this UpdateAccountSettings.

        Set output format to JSON  # noqa: E501

        :param json: The json of this UpdateAccountSettings.  # noqa: E501
        :type: bool
        """

        self._json = json

    @property
    def jwt_ttl_default(self):
        """Gets the jwt_ttl_default of this UpdateAccountSettings.  # noqa: E501

        Default ttl  # noqa: E501

        :return: The jwt_ttl_default of this UpdateAccountSettings.  # noqa: E501
        :rtype: int
        """
        return self._jwt_ttl_default

    @jwt_ttl_default.setter
    def jwt_ttl_default(self, jwt_ttl_default):
        """Sets the jwt_ttl_default of this UpdateAccountSettings.

        Default ttl  # noqa: E501

        :param jwt_ttl_default: The jwt_ttl_default of this UpdateAccountSettings.  # noqa: E501
        :type: int
        """

        self._jwt_ttl_default = jwt_ttl_default

    @property
    def jwt_ttl_max(self):
        """Gets the jwt_ttl_max of this UpdateAccountSettings.  # noqa: E501

        Maximum ttl  # noqa: E501

        :return: The jwt_ttl_max of this UpdateAccountSettings.  # noqa: E501
        :rtype: int
        """
        return self._jwt_ttl_max

    @jwt_ttl_max.setter
    def jwt_ttl_max(self, jwt_ttl_max):
        """Sets the jwt_ttl_max of this UpdateAccountSettings.

        Maximum ttl  # noqa: E501

        :param jwt_ttl_max: The jwt_ttl_max of this UpdateAccountSettings.  # noqa: E501
        :type: int
        """

        self._jwt_ttl_max = jwt_ttl_max

    @property
    def jwt_ttl_min(self):
        """Gets the jwt_ttl_min of this UpdateAccountSettings.  # noqa: E501

        Minimum ttl  # noqa: E501

        :return: The jwt_ttl_min of this UpdateAccountSettings.  # noqa: E501
        :rtype: int
        """
        return self._jwt_ttl_min

    @jwt_ttl_min.setter
    def jwt_ttl_min(self, jwt_ttl_min):
        """Sets the jwt_ttl_min of this UpdateAccountSettings.

        Minimum ttl  # noqa: E501

        :param jwt_ttl_min: The jwt_ttl_min of this UpdateAccountSettings.  # noqa: E501
        :type: int
        """

        self._jwt_ttl_min = jwt_ttl_min

    @property
    def max_versions(self):
        """Gets the max_versions of this UpdateAccountSettings.  # noqa: E501

        Max versions  # noqa: E501

        :return: The max_versions of this UpdateAccountSettings.  # noqa: E501
        :rtype: str
        """
        return self._max_versions

    @max_versions.setter
    def max_versions(self, max_versions):
        """Sets the max_versions of this UpdateAccountSettings.

        Max versions  # noqa: E501

        :param max_versions: The max_versions of this UpdateAccountSettings.  # noqa: E501
        :type: str
        """

        self._max_versions = max_versions

    @property
    def password_length(self):
        """Gets the password_length of this UpdateAccountSettings.  # noqa: E501

        For PasswordPolicy use  # noqa: E501

        :return: The password_length of this UpdateAccountSettings.  # noqa: E501
        :rtype: int
        """
        return self._password_length

    @password_length.setter
    def password_length(self, password_length):
        """Sets the password_length of this UpdateAccountSettings.

        For PasswordPolicy use  # noqa: E501

        :param password_length: The password_length of this UpdateAccountSettings.  # noqa: E501
        :type: int
        """

        self._password_length = password_length

    @property
    def phone(self):
        """Gets the phone of this UpdateAccountSettings.  # noqa: E501

        Phone number  # noqa: E501

        :return: The phone of this UpdateAccountSettings.  # noqa: E501
        :rtype: str
        """
        return self._phone

    @phone.setter
    def phone(self, phone):
        """Sets the phone of this UpdateAccountSettings.

        Phone number  # noqa: E501

        :param phone: The phone of this UpdateAccountSettings.  # noqa: E501
        :type: str
        """

        self._phone = phone

    @property
    def postal_code(self):
        """Gets the postal_code of this UpdateAccountSettings.  # noqa: E501

        Postal code  # noqa: E501

        :return: The postal_code of this UpdateAccountSettings.  # noqa: E501
        :rtype: str
        """
        return self._postal_code

    @postal_code.setter
    def postal_code(self, postal_code):
        """Sets the postal_code of this UpdateAccountSettings.

        Postal code  # noqa: E501

        :param postal_code: The postal_code of this UpdateAccountSettings.  # noqa: E501
        :type: str
        """

        self._postal_code = postal_code

    @property
    def token(self):
        """Gets the token of this UpdateAccountSettings.  # noqa: E501

        Authentication token (see `/auth` and `/configure`)  # noqa: E501

        :return: The token of this UpdateAccountSettings.  # noqa: E501
        :rtype: str
        """
        return self._token

    @token.setter
    def token(self, token):
        """Sets the token of this UpdateAccountSettings.

        Authentication token (see `/auth` and `/configure`)  # noqa: E501

        :param token: The token of this UpdateAccountSettings.  # noqa: E501
        :type: str
        """

        self._token = token

    @property
    def uid_token(self):
        """Gets the uid_token of this UpdateAccountSettings.  # noqa: E501

        The universal identity token, Required only for universal_identity authentication  # noqa: E501

        :return: The uid_token of this UpdateAccountSettings.  # noqa: E501
        :rtype: str
        """
        return self._uid_token

    @uid_token.setter
    def uid_token(self, uid_token):
        """Sets the uid_token of this UpdateAccountSettings.

        The universal identity token, Required only for universal_identity authentication  # noqa: E501

        :param uid_token: The uid_token of this UpdateAccountSettings.  # noqa: E501
        :type: str
        """

        self._uid_token = uid_token

    @property
    def use_lower_letters(self):
        """Gets the use_lower_letters of this UpdateAccountSettings.  # noqa: E501

        For PasswordPolicy use  # noqa: E501

        :return: The use_lower_letters of this UpdateAccountSettings.  # noqa: E501
        :rtype: str
        """
        return self._use_lower_letters

    @use_lower_letters.setter
    def use_lower_letters(self, use_lower_letters):
        """Sets the use_lower_letters of this UpdateAccountSettings.

        For PasswordPolicy use  # noqa: E501

        :param use_lower_letters: The use_lower_letters of this UpdateAccountSettings.  # noqa: E501
        :type: str
        """

        self._use_lower_letters = use_lower_letters

    @property
    def use_numbers(self):
        """Gets the use_numbers of this UpdateAccountSettings.  # noqa: E501

        For PasswordPolicy use  # noqa: E501

        :return: The use_numbers of this UpdateAccountSettings.  # noqa: E501
        :rtype: str
        """
        return self._use_numbers

    @use_numbers.setter
    def use_numbers(self, use_numbers):
        """Sets the use_numbers of this UpdateAccountSettings.

        For PasswordPolicy use  # noqa: E501

        :param use_numbers: The use_numbers of this UpdateAccountSettings.  # noqa: E501
        :type: str
        """

        self._use_numbers = use_numbers

    @property
    def use_special_characters(self):
        """Gets the use_special_characters of this UpdateAccountSettings.  # noqa: E501

        For PasswordPolicy use  # noqa: E501

        :return: The use_special_characters of this UpdateAccountSettings.  # noqa: E501
        :rtype: str
        """
        return self._use_special_characters

    @use_special_characters.setter
    def use_special_characters(self, use_special_characters):
        """Sets the use_special_characters of this UpdateAccountSettings.

        For PasswordPolicy use  # noqa: E501

        :param use_special_characters: The use_special_characters of this UpdateAccountSettings.  # noqa: E501
        :type: str
        """

        self._use_special_characters = use_special_characters

    @property
    def use_capital_letters(self):
        """Gets the use_capital_letters of this UpdateAccountSettings.  # noqa: E501

        For PasswordPolicy use  # noqa: E501

        :return: The use_capital_letters of this UpdateAccountSettings.  # noqa: E501
        :rtype: str
        """
        return self._use_capital_letters

    @use_capital_letters.setter
    def use_capital_letters(self, use_capital_letters):
        """Sets the use_capital_letters of this UpdateAccountSettings.

        For PasswordPolicy use  # noqa: E501

        :param use_capital_letters: The use_capital_letters of this UpdateAccountSettings.  # noqa: E501
        :type: str
        """

        self._use_capital_letters = use_capital_letters

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateAccountSettings):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, UpdateAccountSettings):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from akeyless.configuration import Configuration


class UpdateManagedKey(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'add_tag': 'list[str]',
        'auto_rotate': 'str',
        'name': 'str',
        'new_metadata': 'str',
        'new_name': 'str',
        'rm_tag': 'list[str]',
        'rotation_interval': 'str',
        'token': 'str',
        'uid_token': 'str',
        'update_url': 'str'
    }

    attribute_map = {
        'add_tag': 'add-tag',
        'auto_rotate': 'auto-rotate',
        'name': 'name',
        'new_metadata': 'new-metadata',
        'new_name': 'new-name',
        'rm_tag': 'rm-tag',
        'rotation_interval': 'rotation-interval',
        'token': 'token',
        'uid_token': 'uid-token',
        'update_url': 'update-url'
    }

    def __init__(self, add_tag=None, auto_rotate=None, name=None, new_metadata='default_metadata', new_name=None, rm_tag=None, rotation_interval=None, token=None, uid_token=None, update_url='http://localhost:8000', local_vars_configuration=None):  # noqa: E501
        """UpdateManagedKey - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._add_tag = None
        self._auto_rotate = None
        self._name = None
        self._new_metadata = None
        self._new_name = None
        self._rm_tag = None
        self._rotation_interval = None
        self._token = None
        self._uid_token = None
        self._update_url = None
        self.discriminator = None

        if add_tag is not None:
            self.add_tag = add_tag
        if auto_rotate is not None:
            self.auto_rotate = auto_rotate
        self.name = name
        if new_metadata is not None:
            self.new_metadata = new_metadata
        if new_name is not None:
            self.new_name = new_name
        if rm_tag is not None:
            self.rm_tag = rm_tag
        if rotation_interval is not None:
            self.rotation_interval = rotation_interval
        if token is not None:
            self.token = token
        if uid_token is not None:
            self.uid_token = uid_token
        if update_url is not None:
            self.update_url = update_url

    @property
    def add_tag(self):
        """Gets the add_tag of this UpdateManagedKey.  # noqa: E501

        List of the new tags that will be attached to this item  # noqa: E501

        :return: The add_tag of this UpdateManagedKey.  # noqa: E501
        :rtype: list[str]
        """
        return self._add_tag

    @add_tag.setter
    def add_tag(self, add_tag):
        """Sets the add_tag of this UpdateManagedKey.

        List of the new tags that will be attached to this item  # noqa: E501

        :param add_tag: The add_tag of this UpdateManagedKey.  # noqa: E501
        :type: list[str]
        """

        self._add_tag = add_tag

    @property
    def auto_rotate(self):
        """Gets the auto_rotate of this UpdateManagedKey.  # noqa: E501

        Whether to automatically rotate every --rotation-interval days, or disable existing automatic rotation  # noqa: E501

        :return: The auto_rotate of this UpdateManagedKey.  # noqa: E501
        :rtype: str
        """
        return self._auto_rotate

    @auto_rotate.setter
    def auto_rotate(self, auto_rotate):
        """Sets the auto_rotate of this UpdateManagedKey.

        Whether to automatically rotate every --rotation-interval days, or disable existing automatic rotation  # noqa: E501

        :param auto_rotate: The auto_rotate of this UpdateManagedKey.  # noqa: E501
        :type: str
        """

        self._auto_rotate = auto_rotate

    @property
    def name(self):
        """Gets the name of this UpdateManagedKey.  # noqa: E501

        ManagedKey name  # noqa: E501

        :return: The name of this UpdateManagedKey.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this UpdateManagedKey.

        ManagedKey name  # noqa: E501

        :param name: The name of this UpdateManagedKey.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def new_metadata(self):
        """Gets the new_metadata of this UpdateManagedKey.  # noqa: E501

        New item metadata  # noqa: E501

        :return: The new_metadata of this UpdateManagedKey.  # noqa: E501
        :rtype: str
        """
        return self._new_metadata

    @new_metadata.setter
    def new_metadata(self, new_metadata):
        """Sets the new_metadata of this UpdateManagedKey.

        New item metadata  # noqa: E501

        :param new_metadata: The new_metadata of this UpdateManagedKey.  # noqa: E501
        :type: str
        """

        self._new_metadata = new_metadata

    @property
    def new_name(self):
        """Gets the new_name of this UpdateManagedKey.  # noqa: E501

        New managed key name  # noqa: E501

        :return: The new_name of this UpdateManagedKey.  # noqa: E501
        :rtype: str
        """
        return self._new_name

    @new_name.setter
    def new_name(self, new_name):
        """Sets the new_name of this UpdateManagedKey.

        New managed key name  # noqa: E501

        :param new_name: The new_name of this UpdateManagedKey.  # noqa: E501
        :type: str
        """

        self._new_name = new_name

    @property
    def rm_tag(self):
        """Gets the rm_tag of this UpdateManagedKey.  # noqa: E501

        List of the existent tags that will be removed from this item  # noqa: E501

        :return: The rm_tag of this UpdateManagedKey.  # noqa: E501
        :rtype: list[str]
        """
        return self._rm_tag

    @rm_tag.setter
    def rm_tag(self, rm_tag):
        """Sets the rm_tag of this UpdateManagedKey.

        List of the existent tags that will be removed from this item  # noqa: E501

        :param rm_tag: The rm_tag of this UpdateManagedKey.  # noqa: E501
        :type: list[str]
        """

        self._rm_tag = rm_tag

    @property
    def rotation_interval(self):
        """Gets the rotation_interval of this UpdateManagedKey.  # noqa: E501

        The number of days to wait between every automatic key rotation (7-365)  # noqa: E501

        :return: The rotation_interval of this UpdateManagedKey.  # noqa: E501
        :rtype: str
        """
        return self._rotation_interval

    @rotation_interval.setter
    def rotation_interval(self, rotation_interval):
        """Sets the rotation_interval of this UpdateManagedKey.

        The number of days to wait between every automatic key rotation (7-365)  # noqa: E501

        :param rotation_interval: The rotation_interval of this UpdateManagedKey.  # noqa: E501
        :type: str
        """

        self._rotation_interval = rotation_interval

    @property
    def token(self):
        """Gets the token of this UpdateManagedKey.  # noqa: E501

        Authentication token (see `/auth` and `/configure`)  # noqa: E501

        :return: The token of this UpdateManagedKey.  # noqa: E501
        :rtype: str
        """
        return self._token

    @token.setter
    def token(self, token):
        """Sets the token of this UpdateManagedKey.

        Authentication token (see `/auth` and `/configure`)  # noqa: E501

        :param token: The token of this UpdateManagedKey.  # noqa: E501
        :type: str
        """

        self._token = token

    @property
    def uid_token(self):
        """Gets the uid_token of this UpdateManagedKey.  # noqa: E501

        The universal identity token, Required only for universal_identity authentication  # noqa: E501

        :return: The uid_token of this UpdateManagedKey.  # noqa: E501
        :rtype: str
        """
        return self._uid_token

    @uid_token.setter
    def uid_token(self, uid_token):
        """Sets the uid_token of this UpdateManagedKey.

        The universal identity token, Required only for universal_identity authentication  # noqa: E501

        :param uid_token: The uid_token of this UpdateManagedKey.  # noqa: E501
        :type: str
        """

        self._uid_token = uid_token

    @property
    def update_url(self):
        """Gets the update_url of this UpdateManagedKey.  # noqa: E501

        Gateway url  # noqa: E501

        :return: The update_url of this UpdateManagedKey.  # noqa: E501
        :rtype: str
        """
        return self._update_url

    @update_url.setter
    def update_url(self, update_url):
        """Sets the update_url of this UpdateManagedKey.

        Gateway url  # noqa: E501

        :param update_url: The update_url of this UpdateManagedKey.  # noqa: E501
        :type: str
        """

        self._update_url = update_url

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateManagedKey):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, UpdateManagedKey):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from akeyless.configuration import Configuration


class GwClusterIdentity(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'allowed': 'bool',
        'allowed_access_ids': 'list[str]',
        'cluster_name': 'str',
        'cluster_url': 'str',
        'current_gw': 'bool',
        'customer_fragment_ids': 'list[str]',
        'default_protection_key_id': 'int',
        'default_secret_location': 'str',
        'display_name': 'str',
        'id': 'int',
        'status': 'str',
        'status_description': 'str'
    }

    attribute_map = {
        'allowed': 'allowed',
        'allowed_access_ids': 'allowed_access_ids',
        'cluster_name': 'cluster_name',
        'cluster_url': 'cluster_url',
        'current_gw': 'current_gw',
        'customer_fragment_ids': 'customer_fragment_ids',
        'default_protection_key_id': 'default_protection_key_id',
        'default_secret_location': 'default_secret_location',
        'display_name': 'display_name',
        'id': 'id',
        'status': 'status',
        'status_description': 'status_description'
    }

    def __init__(self, allowed=None, allowed_access_ids=None, cluster_name=None, cluster_url=None, current_gw=None, customer_fragment_ids=None, default_protection_key_id=None, default_secret_location=None, display_name=None, id=None, status=None, status_description=None, local_vars_configuration=None):  # noqa: E501
        """GwClusterIdentity - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._allowed = None
        self._allowed_access_ids = None
        self._cluster_name = None
        self._cluster_url = None
        self._current_gw = None
        self._customer_fragment_ids = None
        self._default_protection_key_id = None
        self._default_secret_location = None
        self._display_name = None
        self._id = None
        self._status = None
        self._status_description = None
        self.discriminator = None

        if allowed is not None:
            self.allowed = allowed
        if allowed_access_ids is not None:
            self.allowed_access_ids = allowed_access_ids
        if cluster_name is not None:
            self.cluster_name = cluster_name
        if cluster_url is not None:
            self.cluster_url = cluster_url
        if current_gw is not None:
            self.current_gw = current_gw
        if customer_fragment_ids is not None:
            self.customer_fragment_ids = customer_fragment_ids
        if default_protection_key_id is not None:
            self.default_protection_key_id = default_protection_key_id
        if default_secret_location is not None:
            self.default_secret_location = default_secret_location
        if display_name is not None:
            self.display_name = display_name
        if id is not None:
            self.id = id
        if status is not None:
            self.status = status
        if status_description is not None:
            self.status_description = status_description

    @property
    def allowed(self):
        """Gets the allowed of this GwClusterIdentity.  # noqa: E501


        :return: The allowed of this GwClusterIdentity.  # noqa: E501
        :rtype: bool
        """
        return self._allowed

    @allowed.setter
    def allowed(self, allowed):
        """Sets the allowed of this GwClusterIdentity.


        :param allowed: The allowed of this GwClusterIdentity.  # noqa: E501
        :type: bool
        """

        self._allowed = allowed

    @property
    def allowed_access_ids(self):
        """Gets the allowed_access_ids of this GwClusterIdentity.  # noqa: E501


        :return: The allowed_access_ids of this GwClusterIdentity.  # noqa: E501
        :rtype: list[str]
        """
        return self._allowed_access_ids

    @allowed_access_ids.setter
    def allowed_access_ids(self, allowed_access_ids):
        """Sets the allowed_access_ids of this GwClusterIdentity.


        :param allowed_access_ids: The allowed_access_ids of this GwClusterIdentity.  # noqa: E501
        :type: list[str]
        """

        self._allowed_access_ids = allowed_access_ids

    @property
    def cluster_name(self):
        """Gets the cluster_name of this GwClusterIdentity.  # noqa: E501


        :return: The cluster_name of this GwClusterIdentity.  # noqa: E501
        :rtype: str
        """
        return self._cluster_name

    @cluster_name.setter
    def cluster_name(self, cluster_name):
        """Sets the cluster_name of this GwClusterIdentity.


        :param cluster_name: The cluster_name of this GwClusterIdentity.  # noqa: E501
        :type: str
        """

        self._cluster_name = cluster_name

    @property
    def cluster_url(self):
        """Gets the cluster_url of this GwClusterIdentity.  # noqa: E501


        :return: The cluster_url of this GwClusterIdentity.  # noqa: E501
        :rtype: str
        """
        return self._cluster_url

    @cluster_url.setter
    def cluster_url(self, cluster_url):
        """Sets the cluster_url of this GwClusterIdentity.


        :param cluster_url: The cluster_url of this GwClusterIdentity.  # noqa: E501
        :type: str
        """

        self._cluster_url = cluster_url

    @property
    def current_gw(self):
        """Gets the current_gw of this GwClusterIdentity.  # noqa: E501


        :return: The current_gw of this GwClusterIdentity.  # noqa: E501
        :rtype: bool
        """
        return self._current_gw

    @current_gw.setter
    def current_gw(self, current_gw):
        """Sets the current_gw of this GwClusterIdentity.


        :param current_gw: The current_gw of this GwClusterIdentity.  # noqa: E501
        :type: bool
        """

        self._current_gw = current_gw

    @property
    def customer_fragment_ids(self):
        """Gets the customer_fragment_ids of this GwClusterIdentity.  # noqa: E501


        :return: The customer_fragment_ids of this GwClusterIdentity.  # noqa: E501
        :rtype: list[str]
        """
        return self._customer_fragment_ids

    @customer_fragment_ids.setter
    def customer_fragment_ids(self, customer_fragment_ids):
        """Sets the customer_fragment_ids of this GwClusterIdentity.


        :param customer_fragment_ids: The customer_fragment_ids of this GwClusterIdentity.  # noqa: E501
        :type: list[str]
        """

        self._customer_fragment_ids = customer_fragment_ids

    @property
    def default_protection_key_id(self):
        """Gets the default_protection_key_id of this GwClusterIdentity.  # noqa: E501


        :return: The default_protection_key_id of this GwClusterIdentity.  # noqa: E501
        :rtype: int
        """
        return self._default_protection_key_id

    @default_protection_key_id.setter
    def default_protection_key_id(self, default_protection_key_id):
        """Sets the default_protection_key_id of this GwClusterIdentity.


        :param default_protection_key_id: The default_protection_key_id of this GwClusterIdentity.  # noqa: E501
        :type: int
        """

        self._default_protection_key_id = default_protection_key_id

    @property
    def default_secret_location(self):
        """Gets the default_secret_location of this GwClusterIdentity.  # noqa: E501


        :return: The default_secret_location of this GwClusterIdentity.  # noqa: E501
        :rtype: str
        """
        return self._default_secret_location

    @default_secret_location.setter
    def default_secret_location(self, default_secret_location):
        """Sets the default_secret_location of this GwClusterIdentity.


        :param default_secret_location: The default_secret_location of this GwClusterIdentity.  # noqa: E501
        :type: str
        """

        self._default_secret_location = default_secret_location

    @property
    def display_name(self):
        """Gets the display_name of this GwClusterIdentity.  # noqa: E501


        :return: The display_name of this GwClusterIdentity.  # noqa: E501
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """Sets the display_name of this GwClusterIdentity.


        :param display_name: The display_name of this GwClusterIdentity.  # noqa: E501
        :type: str
        """

        self._display_name = display_name

    @property
    def id(self):
        """Gets the id of this GwClusterIdentity.  # noqa: E501


        :return: The id of this GwClusterIdentity.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this GwClusterIdentity.


        :param id: The id of this GwClusterIdentity.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def status(self):
        """Gets the status of this GwClusterIdentity.  # noqa: E501


        :return: The status of this GwClusterIdentity.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this GwClusterIdentity.


        :param status: The status of this GwClusterIdentity.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def status_description(self):
        """Gets the status_description of this GwClusterIdentity.  # noqa: E501


        :return: The status_description of this GwClusterIdentity.  # noqa: E501
        :rtype: str
        """
        return self._status_description

    @status_description.setter
    def status_description(self, status_description):
        """Sets the status_description of this GwClusterIdentity.


        :param status_description: The status_description of this GwClusterIdentity.  # noqa: E501
        :type: str
        """

        self._status_description = status_description

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GwClusterIdentity):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, GwClusterIdentity):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from akeyless.configuration import Configuration


class AWSIAMAccessRules(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'account_id': 'list[str]',
        'arn': 'list[str]',
        'resource_id': 'list[str]',
        'role_id': 'list[str]',
        'role_name': 'list[str]',
        'sts_endpoint': 'str',
        'user_id': 'list[str]',
        'user_name': 'list[str]'
    }

    attribute_map = {
        'account_id': 'account_id',
        'arn': 'arn',
        'resource_id': 'resource_id',
        'role_id': 'role_id',
        'role_name': 'role_name',
        'sts_endpoint': 'sts_endpoint',
        'user_id': 'user_id',
        'user_name': 'user_name'
    }

    def __init__(self, account_id=None, arn=None, resource_id=None, role_id=None, role_name=None, sts_endpoint=None, user_id=None, user_name=None, local_vars_configuration=None):  # noqa: E501
        """AWSIAMAccessRules - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._account_id = None
        self._arn = None
        self._resource_id = None
        self._role_id = None
        self._role_name = None
        self._sts_endpoint = None
        self._user_id = None
        self._user_name = None
        self.discriminator = None

        if account_id is not None:
            self.account_id = account_id
        if arn is not None:
            self.arn = arn
        if resource_id is not None:
            self.resource_id = resource_id
        if role_id is not None:
            self.role_id = role_id
        if role_name is not None:
            self.role_name = role_name
        if sts_endpoint is not None:
            self.sts_endpoint = sts_endpoint
        if user_id is not None:
            self.user_id = user_id
        if user_name is not None:
            self.user_name = user_name

    @property
    def account_id(self):
        """Gets the account_id of this AWSIAMAccessRules.  # noqa: E501

        The list of account ids that the login is restricted to.  # noqa: E501

        :return: The account_id of this AWSIAMAccessRules.  # noqa: E501
        :rtype: list[str]
        """
        return self._account_id

    @account_id.setter
    def account_id(self, account_id):
        """Sets the account_id of this AWSIAMAccessRules.

        The list of account ids that the login is restricted to.  # noqa: E501

        :param account_id: The account_id of this AWSIAMAccessRules.  # noqa: E501
        :type: list[str]
        """

        self._account_id = account_id

    @property
    def arn(self):
        """Gets the arn of this AWSIAMAccessRules.  # noqa: E501

        The list of ARNs that the login is restricted to.  # noqa: E501

        :return: The arn of this AWSIAMAccessRules.  # noqa: E501
        :rtype: list[str]
        """
        return self._arn

    @arn.setter
    def arn(self, arn):
        """Sets the arn of this AWSIAMAccessRules.

        The list of ARNs that the login is restricted to.  # noqa: E501

        :param arn: The arn of this AWSIAMAccessRules.  # noqa: E501
        :type: list[str]
        """

        self._arn = arn

    @property
    def resource_id(self):
        """Gets the resource_id of this AWSIAMAccessRules.  # noqa: E501

        The list of resource ids that the login is restricted to.  # noqa: E501

        :return: The resource_id of this AWSIAMAccessRules.  # noqa: E501
        :rtype: list[str]
        """
        return self._resource_id

    @resource_id.setter
    def resource_id(self, resource_id):
        """Sets the resource_id of this AWSIAMAccessRules.

        The list of resource ids that the login is restricted to.  # noqa: E501

        :param resource_id: The resource_id of this AWSIAMAccessRules.  # noqa: E501
        :type: list[str]
        """

        self._resource_id = resource_id

    @property
    def role_id(self):
        """Gets the role_id of this AWSIAMAccessRules.  # noqa: E501

        The list of role ids that the login is restricted to.  # noqa: E501

        :return: The role_id of this AWSIAMAccessRules.  # noqa: E501
        :rtype: list[str]
        """
        return self._role_id

    @role_id.setter
    def role_id(self, role_id):
        """Sets the role_id of this AWSIAMAccessRules.

        The list of role ids that the login is restricted to.  # noqa: E501

        :param role_id: The role_id of this AWSIAMAccessRules.  # noqa: E501
        :type: list[str]
        """

        self._role_id = role_id

    @property
    def role_name(self):
        """Gets the role_name of this AWSIAMAccessRules.  # noqa: E501

        The list of role names that the login is restricted to.  # noqa: E501

        :return: The role_name of this AWSIAMAccessRules.  # noqa: E501
        :rtype: list[str]
        """
        return self._role_name

    @role_name.setter
    def role_name(self, role_name):
        """Sets the role_name of this AWSIAMAccessRules.

        The list of role names that the login is restricted to.  # noqa: E501

        :param role_name: The role_name of this AWSIAMAccessRules.  # noqa: E501
        :type: list[str]
        """

        self._role_name = role_name

    @property
    def sts_endpoint(self):
        """Gets the sts_endpoint of this AWSIAMAccessRules.  # noqa: E501

        The sts URL.  # noqa: E501

        :return: The sts_endpoint of this AWSIAMAccessRules.  # noqa: E501
        :rtype: str
        """
        return self._sts_endpoint

    @sts_endpoint.setter
    def sts_endpoint(self, sts_endpoint):
        """Sets the sts_endpoint of this AWSIAMAccessRules.

        The sts URL.  # noqa: E501

        :param sts_endpoint: The sts_endpoint of this AWSIAMAccessRules.  # noqa: E501
        :type: str
        """

        self._sts_endpoint = sts_endpoint

    @property
    def user_id(self):
        """Gets the user_id of this AWSIAMAccessRules.  # noqa: E501

        The list of user ids that the login is restricted to.  # noqa: E501

        :return: The user_id of this AWSIAMAccessRules.  # noqa: E501
        :rtype: list[str]
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this AWSIAMAccessRules.

        The list of user ids that the login is restricted to.  # noqa: E501

        :param user_id: The user_id of this AWSIAMAccessRules.  # noqa: E501
        :type: list[str]
        """

        self._user_id = user_id

    @property
    def user_name(self):
        """Gets the user_name of this AWSIAMAccessRules.  # noqa: E501

        The list of user names that the login is restricted to.  # noqa: E501

        :return: The user_name of this AWSIAMAccessRules.  # noqa: E501
        :rtype: list[str]
        """
        return self._user_name

    @user_name.setter
    def user_name(self, user_name):
        """Sets the user_name of this AWSIAMAccessRules.

        The list of user names that the login is restricted to.  # noqa: E501

        :param user_name: The user_name of this AWSIAMAccessRules.  # noqa: E501
        :type: list[str]
        """

        self._user_name = user_name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AWSIAMAccessRules):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AWSIAMAccessRules):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from akeyless.configuration import Configuration


class UpdateLdapTarget(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'bind_dn': 'str',
        'bind_dn_password': 'str',
        'comment': 'str',
        'json': 'bool',
        'keep_prev_version': 'str',
        'key': 'str',
        'ldap_ca_cert': 'str',
        'ldap_url': 'str',
        'name': 'str',
        'new_name': 'str',
        'server_type': 'str',
        'token': 'str',
        'token_expiration': 'str',
        'uid_token': 'str',
        'update_version': 'bool'
    }

    attribute_map = {
        'bind_dn': 'bind-dn',
        'bind_dn_password': 'bind-dn-password',
        'comment': 'comment',
        'json': 'json',
        'keep_prev_version': 'keep-prev-version',
        'key': 'key',
        'ldap_ca_cert': 'ldap-ca-cert',
        'ldap_url': 'ldap-url',
        'name': 'name',
        'new_name': 'new-name',
        'server_type': 'server-type',
        'token': 'token',
        'token_expiration': 'token-expiration',
        'uid_token': 'uid-token',
        'update_version': 'update-version'
    }

    def __init__(self, bind_dn=None, bind_dn_password=None, comment=None, json=None, keep_prev_version=None, key=None, ldap_ca_cert=None, ldap_url=None, name=None, new_name=None, server_type=None, token=None, token_expiration=None, uid_token=None, update_version=None, local_vars_configuration=None):  # noqa: E501
        """UpdateLdapTarget - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._bind_dn = None
        self._bind_dn_password = None
        self._comment = None
        self._json = None
        self._keep_prev_version = None
        self._key = None
        self._ldap_ca_cert = None
        self._ldap_url = None
        self._name = None
        self._new_name = None
        self._server_type = None
        self._token = None
        self._token_expiration = None
        self._uid_token = None
        self._update_version = None
        self.discriminator = None

        if bind_dn is not None:
            self.bind_dn = bind_dn
        if bind_dn_password is not None:
            self.bind_dn_password = bind_dn_password
        if comment is not None:
            self.comment = comment
        if json is not None:
            self.json = json
        if keep_prev_version is not None:
            self.keep_prev_version = keep_prev_version
        if key is not None:
            self.key = key
        if ldap_ca_cert is not None:
            self.ldap_ca_cert = ldap_ca_cert
        if ldap_url is not None:
            self.ldap_url = ldap_url
        self.name = name
        if new_name is not None:
            self.new_name = new_name
        if server_type is not None:
            self.server_type = server_type
        if token is not None:
            self.token = token
        if token_expiration is not None:
            self.token_expiration = token_expiration
        if uid_token is not None:
            self.uid_token = uid_token
        if update_version is not None:
            self.update_version = update_version

    @property
    def bind_dn(self):
        """Gets the bind_dn of this UpdateLdapTarget.  # noqa: E501


        :return: The bind_dn of this UpdateLdapTarget.  # noqa: E501
        :rtype: str
        """
        return self._bind_dn

    @bind_dn.setter
    def bind_dn(self, bind_dn):
        """Sets the bind_dn of this UpdateLdapTarget.


        :param bind_dn: The bind_dn of this UpdateLdapTarget.  # noqa: E501
        :type: str
        """

        self._bind_dn = bind_dn

    @property
    def bind_dn_password(self):
        """Gets the bind_dn_password of this UpdateLdapTarget.  # noqa: E501


        :return: The bind_dn_password of this UpdateLdapTarget.  # noqa: E501
        :rtype: str
        """
        return self._bind_dn_password

    @bind_dn_password.setter
    def bind_dn_password(self, bind_dn_password):
        """Sets the bind_dn_password of this UpdateLdapTarget.


        :param bind_dn_password: The bind_dn_password of this UpdateLdapTarget.  # noqa: E501
        :type: str
        """

        self._bind_dn_password = bind_dn_password

    @property
    def comment(self):
        """Gets the comment of this UpdateLdapTarget.  # noqa: E501

        Comment about the target  # noqa: E501

        :return: The comment of this UpdateLdapTarget.  # noqa: E501
        :rtype: str
        """
        return self._comment

    @comment.setter
    def comment(self, comment):
        """Sets the comment of this UpdateLdapTarget.

        Comment about the target  # noqa: E501

        :param comment: The comment of this UpdateLdapTarget.  # noqa: E501
        :type: str
        """

        self._comment = comment

    @property
    def json(self):
        """Gets the json of this UpdateLdapTarget.  # noqa: E501

        Set output format to JSON  # noqa: E501

        :return: The json of this UpdateLdapTarget.  # noqa: E501
        :rtype: bool
        """
        return self._json

    @json.setter
    def json(self, json):
        """Sets the json of this UpdateLdapTarget.

        Set output format to JSON  # noqa: E501

        :param json: The json of this UpdateLdapTarget.  # noqa: E501
        :type: bool
        """

        self._json = json

    @property
    def keep_prev_version(self):
        """Gets the keep_prev_version of this UpdateLdapTarget.  # noqa: E501


        :return: The keep_prev_version of this UpdateLdapTarget.  # noqa: E501
        :rtype: str
        """
        return self._keep_prev_version

    @keep_prev_version.setter
    def keep_prev_version(self, keep_prev_version):
        """Sets the keep_prev_version of this UpdateLdapTarget.


        :param keep_prev_version: The keep_prev_version of this UpdateLdapTarget.  # noqa: E501
        :type: str
        """

        self._keep_prev_version = keep_prev_version

    @property
    def key(self):
        """Gets the key of this UpdateLdapTarget.  # noqa: E501

        The name of a key that used to encrypt the target secret value (if empty, the account default protectionKey key will be used)  # noqa: E501

        :return: The key of this UpdateLdapTarget.  # noqa: E501
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        """Sets the key of this UpdateLdapTarget.

        The name of a key that used to encrypt the target secret value (if empty, the account default protectionKey key will be used)  # noqa: E501

        :param key: The key of this UpdateLdapTarget.  # noqa: E501
        :type: str
        """

        self._key = key

    @property
    def ldap_ca_cert(self):
        """Gets the ldap_ca_cert of this UpdateLdapTarget.  # noqa: E501


        :return: The ldap_ca_cert of this UpdateLdapTarget.  # noqa: E501
        :rtype: str
        """
        return self._ldap_ca_cert

    @ldap_ca_cert.setter
    def ldap_ca_cert(self, ldap_ca_cert):
        """Sets the ldap_ca_cert of this UpdateLdapTarget.


        :param ldap_ca_cert: The ldap_ca_cert of this UpdateLdapTarget.  # noqa: E501
        :type: str
        """

        self._ldap_ca_cert = ldap_ca_cert

    @property
    def ldap_url(self):
        """Gets the ldap_url of this UpdateLdapTarget.  # noqa: E501


        :return: The ldap_url of this UpdateLdapTarget.  # noqa: E501
        :rtype: str
        """
        return self._ldap_url

    @ldap_url.setter
    def ldap_url(self, ldap_url):
        """Sets the ldap_url of this UpdateLdapTarget.


        :param ldap_url: The ldap_url of this UpdateLdapTarget.  # noqa: E501
        :type: str
        """

        self._ldap_url = ldap_url

    @property
    def name(self):
        """Gets the name of this UpdateLdapTarget.  # noqa: E501

        Target name  # noqa: E501

        :return: The name of this UpdateLdapTarget.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this UpdateLdapTarget.

        Target name  # noqa: E501

        :param name: The name of this UpdateLdapTarget.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def new_name(self):
        """Gets the new_name of this UpdateLdapTarget.  # noqa: E501

        New target name  # noqa: E501

        :return: The new_name of this UpdateLdapTarget.  # noqa: E501
        :rtype: str
        """
        return self._new_name

    @new_name.setter
    def new_name(self, new_name):
        """Sets the new_name of this UpdateLdapTarget.

        New target name  # noqa: E501

        :param new_name: The new_name of this UpdateLdapTarget.  # noqa: E501
        :type: str
        """

        self._new_name = new_name

    @property
    def server_type(self):
        """Gets the server_type of this UpdateLdapTarget.  # noqa: E501

        Set Ldap server type, Options:[OpenLDAP, ActiveDirectory]  # noqa: E501

        :return: The server_type of this UpdateLdapTarget.  # noqa: E501
        :rtype: str
        """
        return self._server_type

    @server_type.setter
    def server_type(self, server_type):
        """Sets the server_type of this UpdateLdapTarget.

        Set Ldap server type, Options:[OpenLDAP, ActiveDirectory]  # noqa: E501

        :param server_type: The server_type of this UpdateLdapTarget.  # noqa: E501
        :type: str
        """

        self._server_type = server_type

    @property
    def token(self):
        """Gets the token of this UpdateLdapTarget.  # noqa: E501

        Authentication token (see `/auth` and `/configure`)  # noqa: E501

        :return: The token of this UpdateLdapTarget.  # noqa: E501
        :rtype: str
        """
        return self._token

    @token.setter
    def token(self, token):
        """Sets the token of this UpdateLdapTarget.

        Authentication token (see `/auth` and `/configure`)  # noqa: E501

        :param token: The token of this UpdateLdapTarget.  # noqa: E501
        :type: str
        """

        self._token = token

    @property
    def token_expiration(self):
        """Gets the token_expiration of this UpdateLdapTarget.  # noqa: E501


        :return: The token_expiration of this UpdateLdapTarget.  # noqa: E501
        :rtype: str
        """
        return self._token_expiration

    @token_expiration.setter
    def token_expiration(self, token_expiration):
        """Sets the token_expiration of this UpdateLdapTarget.


        :param token_expiration: The token_expiration of this UpdateLdapTarget.  # noqa: E501
        :type: str
        """

        self._token_expiration = token_expiration

    @property
    def uid_token(self):
        """Gets the uid_token of this UpdateLdapTarget.  # noqa: E501

        The universal identity token, Required only for universal_identity authentication  # noqa: E501

        :return: The uid_token of this UpdateLdapTarget.  # noqa: E501
        :rtype: str
        """
        return self._uid_token

    @uid_token.setter
    def uid_token(self, uid_token):
        """Sets the uid_token of this UpdateLdapTarget.

        The universal identity token, Required only for universal_identity authentication  # noqa: E501

        :param uid_token: The uid_token of this UpdateLdapTarget.  # noqa: E501
        :type: str
        """

        self._uid_token = uid_token

    @property
    def update_version(self):
        """Gets the update_version of this UpdateLdapTarget.  # noqa: E501

        Deprecated  # noqa: E501

        :return: The update_version of this UpdateLdapTarget.  # noqa: E501
        :rtype: bool
        """
        return self._update_version

    @update_version.setter
    def update_version(self, update_version):
        """Sets the update_version of this UpdateLdapTarget.

        Deprecated  # noqa: E501

        :param update_version: The update_version of this UpdateLdapTarget.  # noqa: E501
        :type: bool
        """

        self._update_version = update_version

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateLdapTarget):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, UpdateLdapTarget):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import akeyless
from akeyless.models.gateway_update_producer_hana_db_output import GatewayUpdateProducerHanaDbOutput  # noqa: E501
from akeyless.rest import ApiException

class TestGatewayUpdateProducerHanaDbOutput(unittest.TestCase):
    """GatewayUpdateProducerHanaDbOutput unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test GatewayUpdateProducerHanaDbOutput
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = akeyless.models.gateway_update_producer_hana_db_output.GatewayUpdateProducerHanaDbOutput()  # noqa: E501
        if include_optional :
            return GatewayUpdateProducerHanaDbOutput(
                producer_details = akeyless.models.ds_producer_details.DSProducerDetails(
                    active = True, 
                    admin_name = '0', 
                    admin_pwd = '0', 
                    admin_rotation_interval_days = 56, 
                    artifactory_admin_apikey = '0', 
                    artifactory_admin_username = '0', 
                    artifactory_base_url = '0', 
                    artifactory_token_audience = '0', 
                    artifactory_token_scope = '0', 
                    aws_access_key_id = '0', 
                    aws_access_mode = '0', 
                    aws_region = '0', 
                    aws_role_arns = '0', 
                    aws_secret_access_key = '0', 
                    aws_session_token = '0', 
                    aws_user_console_access = True, 
                    aws_user_groups = '0', 
                    aws_user_policies = '0', 
                    aws_user_programmatic_access = True, 
                    azure_app_object_id = '0', 
                    azure_client_id = '0', 
                    azure_client_secret = '0', 
                    azure_fixed_user_name_sub_claim_key = '0', 
                    azure_fixed_user_only = True, 
                    azure_tenant_id = '0', 
                    azure_user_groups_obj_id = '0', 
                    azure_user_portal_access = True, 
                    azure_user_programmatic_access = True, 
                    azure_user_roles_template_id = '0', 
                    cassandra_creation_statements = '0', 
                    chef_organizations = '0', 
                    chef_server_access_mode = '0', 
                    chef_server_host_name = '0', 
                    chef_server_key = '0', 
                    chef_server_port = '0', 
                    chef_server_url = '0', 
                    chef_server_username = '0', 
                    chef_skip_ssl = True, 
                    create_sync_url = '0', 
                    db_host_name = '0', 
                    db_isolation_level = '0', 
                    db_max_idle_conns = '0', 
                    db_max_open_conns = '0', 
                    db_name = '0', 
                    db_port = '0', 
                    db_pwd = '0', 
                    db_server_certificates = '0', 
                    db_server_name = '0', 
                    db_user_name = '0', 
                    dynamic_secret_id = 56, 
                    dynamic_secret_key = '0', 
                    dynamic_secret_name = '0', 
                    dynamic_secret_type = '0', 
                    eks_access_key_id = '0', 
                    eks_assume_role = '0', 
                    eks_cluster_ca_certificate = '0', 
                    eks_cluster_endpoint = '0', 
                    eks_cluster_name = '0', 
                    eks_region = '0', 
                    eks_secret_access_key = '0', 
                    enable_admin_rotation = True, 
                    externally_provided_user = '0', 
                    failure_message = '0', 
                    fixed_user_only = '0', 
                    gcp_key_algo = '0', 
                    gcp_service_account_email = '0', 
                    gcp_service_account_key = '0', 
                    gcp_token_lifetime = '0', 
                    gcp_token_scope = '0', 
                    gcp_token_type = '0', 
                    github_app_id = 56, 
                    github_app_private_key = '0', 
                    github_base_url = '0', 
                    github_installation_id = 56, 
                    github_installation_token_permissions = {
                        'key' : '0'
                        }, 
                    github_installation_token_repositories = [
                        '0'
                        ], 
                    github_installation_token_repositories_ids = [
                        56
                        ], 
                    github_repository_path = '0', 
                    gke_cluster_ca_certificate = '0', 
                    gke_cluster_endpoint = '0', 
                    gke_cluster_name = '0', 
                    gke_service_account_key = '0', 
                    gke_service_account_name = '0', 
                    groups = '0', 
                    hanadb_creation_statements = '0', 
                    hanadb_revocation_statements = '0', 
                    host_name = '0', 
                    host_port = '0', 
                    is_fixed_user = '0', 
                    item_targets_assoc = [
                        akeyless.models.item_target_association.ItemTargetAssociation(
                            assoc_id = '0', 
                            target_id = 56, 
                            target_name = '0', )
                        ], 
                    k8s_bearer_token = '0', 
                    k8s_cluster_ca_certificate = '0', 
                    k8s_cluster_endpoint = '0', 
                    k8s_namespace = '0', 
                    k8s_service_account = '0', 
                    last_admin_rotation = 56, 
                    ldap_audience = '0', 
                    ldap_bind_dn = '0', 
                    ldap_bind_password = '0', 
                    ldap_certificate = '0', 
                    ldap_token_expiration = '0', 
                    ldap_url = '0', 
                    ldap_user_attr = '0', 
                    ldap_user_dn = '0', 
                    mongodb_atlas_api_private_key = '0', 
                    mongodb_atlas_api_public_key = '0', 
                    mongodb_atlas_project_id = '0', 
                    mongodb_custom_data = '0', 
                    mongodb_db_name = '0', 
                    mongodb_default_auth_db = '0', 
                    mongodb_host_port = '0', 
                    mongodb_is_atlas = True, 
                    mongodb_password = '0', 
                    mongodb_roles = '0', 
                    mongodb_uri_connection = '0', 
                    mongodb_uri_options = '0', 
                    mongodb_username = '0', 
                    mssql_creation_statements = '0', 
                    mssql_revocation_statements = '0', 
                    mysql_creation_statements = '0', 
                    oracle_creation_statements = '0', 
                    password = '0', 
                    password_length = 56, 
                    password_policy = '0', 
                    payload = '0', 
                    postgres_creation_statements = '0', 
                    postgres_revocation_statements = '0', 
                    rabbitmq_server_password = '0', 
                    rabbitmq_server_uri = '0', 
                    rabbitmq_server_user = '0', 
                    rabbitmq_user_conf_permission = '0', 
                    rabbitmq_user_read_permission = '0', 
                    rabbitmq_user_tags = '0', 
                    rabbitmq_user_vhost = '0', 
                    rabbitmq_user_write_permission = '0', 
                    redshift_creation_statements = '0', 
                    revoke_sync_url = '0', 
                    rotate_sync_url = '0', 
                    scopes = [
                        '0'
                        ], 
                    secure_remote_access_details = akeyless.models.secure_remote_access.SecureRemoteAccess(
                        account_id = '0', 
                        allow_port_forwarding = True, 
                        allow_providing_external_username = True, 
                        bastion_api = '0', 
                        bastion_issuer = '0', 
                        bastion_issuer_id = 56, 
                        bastion_ssh = '0', 
                        category = '0', 
                        dashboard_url = '0', 
                        db_name = '0', 
                        domain = '0', 
                        enable = True, 
                        endpoint = '0', 
                        host = [
                            '0'
                            ], 
                        is_cli = True, 
                        is_web = True, 
                        isolated = True, 
                        native = True, 
                        rdp_user = '0', 
                        region = '0', 
                        schema = '0', 
                        ssh_password = True, 
                        ssh_private_key = True, 
                        ssh_user = '0', 
                        url = '0', 
                        use_internal_bastion = True, 
                        web_proxy = True, ), 
                    session_extension_warn_interval_min = 56, 
                    sf_account = '0', 
                    sf_user_role = '0', 
                    sf_warehouse_name = '0', 
                    should_stop = '0', 
                    ssl_connection_certificate = '0', 
                    ssl_connection_mode = True, 
                    tags = [
                        '0'
                        ], 
                    timeout_seconds = 56, 
                    use_gw_cloud_identity = True, 
                    user_name = '0', 
                    user_principal_name = '0', 
                    user_ttl = '0', 
                    username_length = 56, 
                    username_policy = '0', 
                    venafi_allow_subdomains = True, 
                    venafi_allowed_domains = [
                        '0'
                        ], 
                    venafi_api_key = '0', 
                    venafi_auto_generated_folder = '0', 
                    venafi_base_url = '0', 
                    venafi_root_first_in_chain = True, 
                    venafi_sign_using_akeyless_pki = True, 
                    venafi_signer_key_name = '0', 
                    venafi_store_private_key = True, 
                    venafi_tpp_password = '0', 
                    venafi_tpp_username = '0', 
                    venafi_use_tpp = True, 
                    venafi_zone = '0', 
                    warn_before_user_expiration_min = 56, )
            )
        else :
            return GatewayUpdateProducerHanaDbOutput(
        )

    def testGatewayUpdateProducerHanaDbOutput(self):
        """Test GatewayUpdateProducerHanaDbOutput"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
